from enum import IntEnum
from typing import overload, NewType, Optional, Tuple

from OCC.Core.Standard import *
from OCC.Core.NCollection import *
from OCC.Core.IFSelect import *
from OCC.Core.TopoDS import *
from OCC.Core.Transfer import *
from OCC.Core.TopAbs import *
from OCC.Core.TColStd import *
from OCC.Core.Interface import *
from OCC.Core.TCollection import *
from OCC.Core.Message import *
from OCC.Core.TopTools import *
from OCC.Core.Geom import *
from OCC.Core.Geom2d import *
from OCC.Core.gp import *


class xscontrol:
	@staticmethod
	def Session(pilot: IFSelect_SessionPilot) -> XSControl_WorkSession: ...
	@staticmethod
	def Vars(pilot: IFSelect_SessionPilot) -> XSControl_Vars: ...

class XSControl_ConnectedShapes(IFSelect_SelectExplore):
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, TR: XSControl_TransferReader) -> None: ...
	@staticmethod
	def AdjacentEntities(ashape: TopoDS_Shape, TP: Transfer_TransientProcess, type: TopAbs_ShapeEnum) -> TColStd_HSequenceOfTransient: ...
	def Explore(self, level: int, ent: Standard_Transient, G: Interface_Graph, explored: Interface_EntityIterator) -> bool: ...
	def ExploreLabel(self) -> TCollection_AsciiString: ...
	def SetReader(self, TR: XSControl_TransferReader) -> None: ...

class XSControl_Controller(Standard_Transient):
	def ActorRead(self, model: Interface_InterfaceModel) -> Transfer_ActorOfTransientProcess: ...
	def ActorWrite(self) -> Transfer_ActorOfFinderProcess: ...
	def AdaptorSession(self) -> False: ...
	def AddSessionItem(self, theItem: Standard_Transient, theName: str, toApply: Optional[bool] = False) -> None: ...
	def AutoRecord(self) -> None: ...
	def Customise(self, WS: XSControl_WorkSession) -> None: ...
	def IsModeWrite(self, modetrans: int, shape: Optional[bool] = True) -> bool: ...
	def ModeWriteBounds(self, shape: Optional[bool] = True) -> Tuple[bool, int, int]: ...
	def ModeWriteHelp(self, modetrans: int, shape: Optional[bool] = True) -> str: ...
	def Name(self, rsc: Optional[bool] = False) -> str: ...
	def NewModel(self) -> Interface_InterfaceModel: ...
	def Protocol(self) -> Interface_Protocol: ...
	def RecognizeWriteShape(self, shape: TopoDS_Shape, modetrans: Optional[int] = 0) -> bool: ...
	def RecognizeWriteTransient(self, obj: Standard_Transient, modetrans: Optional[int] = 0) -> bool: ...
	def Record(self, name: str) -> None: ...
	@staticmethod
	def Recorded(name: str) -> XSControl_Controller: ...
	def SessionItem(self, theName: str) -> Standard_Transient: ...
	def SetModeWrite(self, modemin: int, modemax: int, shape: Optional[bool] = True) -> None: ...
	def SetModeWriteHelp(self, modetrans: int, help: str, shape: Optional[bool] = True) -> None: ...
	def SetNames(self, theLongName: str, theShortName: str) -> None: ...
	def TransferWriteShape(self, shape: TopoDS_Shape, FP: Transfer_FinderProcess, model: Interface_InterfaceModel, modetrans: Optional[int] = 0, theProgress: Optional[Message_ProgressRange] = Message_ProgressRange()) -> IFSelect_ReturnStatus: ...
	def TransferWriteTransient(self, obj: Standard_Transient, FP: Transfer_FinderProcess, model: Interface_InterfaceModel, modetrans: Optional[int] = 0, theProgress: Optional[Message_ProgressRange] = Message_ProgressRange()) -> IFSelect_ReturnStatus: ...
	def WorkLibrary(self) -> IFSelect_WorkLibrary: ...

class XSControl_FuncShape:
	@staticmethod
	def FileAndVar(session: XSControl_WorkSession, file: str, var: str, def_: str, resfile: TCollection_AsciiString, resvar: TCollection_AsciiString) -> bool: ...
	@staticmethod
	def Init() -> None: ...
	@staticmethod
	def MoreShapes(session: XSControl_WorkSession, list: TopTools_HSequenceOfShape, name: str) -> int: ...

class XSControl_Functions:
	@staticmethod
	def Init() -> None: ...

class XSControl_Reader:
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, norm: str) -> None: ...
	@overload
	def __init__(self, WS: XSControl_WorkSession, scratch: Optional[bool] = True) -> None: ...
	def ClearShapes(self) -> None: ...
	def GetStatsTransfer(self, list: TColStd_HSequenceOfTransient) -> Tuple[int, int, int]: ...
	@overload
	def GiveList(self, first: Optional[str] = "", second: Optional[str] = "") -> TColStd_HSequenceOfTransient: ...
	@overload
	def GiveList(self, first: str, ent: Standard_Transient) -> TColStd_HSequenceOfTransient: ...
	def Model(self) -> Interface_InterfaceModel: ...
	def NbRootsForTransfer(self) -> int: ...
	def NbShapes(self) -> int: ...
	def OneShape(self) -> TopoDS_Shape: ...
	@overload
	def PrintCheckLoad(self, failsonly: bool, mode: IFSelect_PrintCount) -> None: ...
	@overload
	def PrintCheckTransfer(self, failsonly: bool, mode: IFSelect_PrintCount) -> None: ...
	@overload
	def PrintStatsTransfer(self, what: int, mode: Optional[int] = 0) -> None: ...
	def ReadFile(self, filename: str) -> IFSelect_ReturnStatus: ...
	def RootForTransfer(self, num: Optional[int] = 1) -> Standard_Transient: ...
	def SetNorm(self, norm: str) -> bool: ...
	def SetWS(self, WS: XSControl_WorkSession, scratch: Optional[bool] = True) -> None: ...
	def Shape(self, num: Optional[int] = 1) -> TopoDS_Shape: ...
	def TransferEntity(self, start: Standard_Transient, theProgress: Optional[Message_ProgressRange] = Message_ProgressRange()) -> bool: ...
	def TransferList(self, list: TColStd_HSequenceOfTransient, theProgress: Optional[Message_ProgressRange] = Message_ProgressRange()) -> int: ...
	def TransferOne(self, num: int, theProgress: Optional[Message_ProgressRange] = Message_ProgressRange()) -> bool: ...
	def TransferOneRoot(self, num: Optional[int] = 1, theProgress: Optional[Message_ProgressRange] = Message_ProgressRange()) -> bool: ...
	def TransferRoots(self, theProgress: Optional[Message_ProgressRange] = Message_ProgressRange()) -> int: ...
	def WS(self) -> XSControl_WorkSession: ...

class XSControl_SelectForTransfer(IFSelect_SelectExtract):
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, TR: XSControl_TransferReader) -> None: ...
	def Actor(self) -> Transfer_ActorOfTransientProcess: ...
	def ExtractLabel(self) -> TCollection_AsciiString: ...
	def Reader(self) -> XSControl_TransferReader: ...
	def SetActor(self, act: Transfer_ActorOfTransientProcess) -> None: ...
	def SetReader(self, TR: XSControl_TransferReader) -> None: ...
	def Sort(self, rank: int, ent: Standard_Transient, model: Interface_InterfaceModel) -> bool: ...

class XSControl_SignTransferStatus(IFSelect_Signature):
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, TR: XSControl_TransferReader) -> None: ...
	def Map(self) -> Transfer_TransientProcess: ...
	def Reader(self) -> XSControl_TransferReader: ...
	def SetMap(self, TP: Transfer_TransientProcess) -> None: ...
	def SetReader(self, TR: XSControl_TransferReader) -> None: ...
	def Value(self, ent: Standard_Transient, model: Interface_InterfaceModel) -> str: ...

class XSControl_TransferReader(Standard_Transient):
	def __init__(self) -> None: ...
	def Actor(self) -> Transfer_ActorOfTransientProcess: ...
	def BeginTransfer(self) -> bool: ...
	def CheckList(self, theEnt: Standard_Transient, theLevel: Optional[int] = 0) -> Interface_CheckIterator: ...
	def CheckedList(self, theEnt: Standard_Transient, WithCheck: Optional[Interface_CheckStatus] = Interface_CheckAny, theResult: Optional[bool] = True) -> TColStd_HSequenceOfTransient: ...
	def Clear(self, theMode: int) -> None: ...
	def ClearResult(self, theEnt: Standard_Transient, theMode: int) -> bool: ...
	def Context(self) -> False: ...
	def EntitiesFromShapeList(self, theRes: TopTools_HSequenceOfShape, theMode: Optional[int] = 0) -> TColStd_HSequenceOfTransient: ...
	def EntityFromResult(self, theRes: Standard_Transient, theMode: Optional[int] = 0) -> Standard_Transient: ...
	def EntityFromShapeResult(self, theRes: TopoDS_Shape, theMode: Optional[int] = 0) -> Standard_Transient: ...
	def FileName(self) -> str: ...
	def FinalEntityLabel(self, theEnt: Standard_Transient) -> str: ...
	def FinalEntityNumber(self, theEnt: Standard_Transient) -> int: ...
	def FinalResult(self, theEnt: Standard_Transient) -> Transfer_ResultFromModel: ...
	def GetContext(self, theName: str, theType: Standard_Type, theCtx: Standard_Transient) -> bool: ...
	def HasChecks(self, theEnt: Standard_Transient, FailsOnly: bool) -> bool: ...
	def HasResult(self, theEnt: Standard_Transient) -> bool: ...
	def IsMarked(self, theEnt: Standard_Transient) -> bool: ...
	def IsRecorded(self, theEnt: Standard_Transient) -> bool: ...
	def IsSkipped(self, theEnt: Standard_Transient) -> bool: ...
	def LastCheckList(self) -> Interface_CheckIterator: ...
	def LastTransferList(self, theRoots: bool) -> TColStd_HSequenceOfTransient: ...
	def Model(self) -> Interface_InterfaceModel: ...
	@staticmethod
	def PrintStatsOnList(theTP: Transfer_TransientProcess, theList: TColStd_HSequenceOfTransient, theWhat: int, theMode: Optional[int] = 0) -> None: ...
	@staticmethod
	def PrintStatsProcess(theTP: Transfer_TransientProcess, theWhat: int, theMode: Optional[int] = 0) -> None: ...
	def Recognize(self, theEnt: Standard_Transient) -> bool: ...
	def RecordResult(self, theEnt: Standard_Transient) -> bool: ...
	def RecordedList(self) -> TColStd_HSequenceOfTransient: ...
	def ResultFromNumber(self, theNum: int) -> Transfer_ResultFromModel: ...
	def SetActor(self, theActor: Transfer_ActorOfTransientProcess) -> None: ...
	def SetContext(self, theName: str, theCtx: Standard_Transient) -> None: ...
	def SetController(self, theControl: XSControl_Controller) -> None: ...
	def SetFileName(self, theName: str) -> None: ...
	def SetGraph(self, theGraph: Interface_HGraph) -> None: ...
	def SetModel(self, theModel: Interface_InterfaceModel) -> None: ...
	def SetTransientProcess(self, theTP: Transfer_TransientProcess) -> None: ...
	def ShapeResult(self, theEnt: Standard_Transient) -> TopoDS_Shape: ...
	def ShapeResultList(self, theRec: bool) -> TopTools_HSequenceOfShape: ...
	def Skip(self, theEnt: Standard_Transient) -> bool: ...
	def TransferClear(self, theEnt: Standard_Transient, theLevel: Optional[int] = 0) -> None: ...
	def TransferList(self, theList: TColStd_HSequenceOfTransient, theRec: Optional[bool] = True, theProgress: Optional[Message_ProgressRange] = Message_ProgressRange()) -> int: ...
	def TransferOne(self, theEnt: Standard_Transient, theRec: Optional[bool] = True, theProgress: Optional[Message_ProgressRange] = Message_ProgressRange()) -> int: ...
	def TransferRoots(self, theGraph: Interface_Graph, theProgress: Optional[Message_ProgressRange] = Message_ProgressRange()) -> int: ...
	def TransientProcess(self) -> Transfer_TransientProcess: ...
	def TransientResult(self, theEnt: Standard_Transient) -> Standard_Transient: ...

class XSControl_TransferWriter(Standard_Transient):
	def __init__(self) -> None: ...
	def CheckList(self) -> Interface_CheckIterator: ...
	def Clear(self, theMode: int) -> None: ...
	def Controller(self) -> XSControl_Controller: ...
	def FinderProcess(self) -> Transfer_FinderProcess: ...
	def PrintStats(self, theWhat: int, theMode: Optional[int] = 0) -> None: ...
	def RecognizeShape(self, theShape: TopoDS_Shape) -> bool: ...
	def RecognizeTransient(self, theObj: Standard_Transient) -> bool: ...
	def ResultCheckList(self, theModel: Interface_InterfaceModel) -> Interface_CheckIterator: ...
	def SetController(self, theCtl: XSControl_Controller) -> None: ...
	def SetFinderProcess(self, theFP: Transfer_FinderProcess) -> None: ...
	def SetTransferMode(self, theMode: int) -> None: ...
	def TransferMode(self) -> int: ...
	def TransferWriteShape(self, theModel: Interface_InterfaceModel, theShape: TopoDS_Shape, theProgress: Optional[Message_ProgressRange] = Message_ProgressRange()) -> IFSelect_ReturnStatus: ...
	def TransferWriteTransient(self, theModel: Interface_InterfaceModel, theObj: Standard_Transient, theProgress: Optional[Message_ProgressRange] = Message_ProgressRange()) -> IFSelect_ReturnStatus: ...

class XSControl_Utils:
	def __init__(self) -> None: ...
	def AppendCStr(self, seqval: TColStd_HSequenceOfHAsciiString, strval: str) -> None: ...
	def AppendEStr(self, seqval: TColStd_HSequenceOfHExtendedString, strval: Standard_ExtString) -> None: ...
	def AppendShape(self, seqv: TopTools_HSequenceOfShape, shape: TopoDS_Shape) -> None: ...
	def AppendTra(self, seqval: TColStd_HSequenceOfTransient, traval: Standard_Transient) -> None: ...
	def ArrToSeq(self, arr: Standard_Transient) -> Standard_Transient: ...
	def AsciiToExtended(self, str: str) -> Standard_ExtString: ...
	def BinderShape(self, tr: Standard_Transient) -> TopoDS_Shape: ...
	def CStrValue(self, list: Standard_Transient, num: int) -> str: ...
	def CompoundFromSeq(self, seqval: TopTools_HSequenceOfShape) -> TopoDS_Shape: ...
	def DateString(self, yy: int, mm: int, dd: int, hh: int, mn: int, ss: int) -> str: ...
	def DateValues(self, text: str) -> Tuple[int, int, int, int, int, int]: ...
	def EStrValue(self, list: Standard_Transient, num: int) -> Standard_ExtString: ...
	def ExtendedToAscii(self, str: Standard_ExtString) -> str: ...
	def IsAscii(self, str: Standard_ExtString) -> bool: ...
	def IsKind(self, item: Standard_Transient, what: Standard_Type) -> bool: ...
	def NewSeqCStr(self) -> TColStd_HSequenceOfHAsciiString: ...
	def NewSeqEStr(self) -> TColStd_HSequenceOfHExtendedString: ...
	def NewSeqShape(self) -> TopTools_HSequenceOfShape: ...
	def NewSeqTra(self) -> TColStd_HSequenceOfTransient: ...
	def SeqIntValue(self, list: TColStd_HSequenceOfInteger, num: int) -> int: ...
	def SeqLength(self, list: Standard_Transient) -> int: ...
	def SeqToArr(self, seq: Standard_Transient, first: Optional[int] = 1) -> Standard_Transient: ...
	def ShapeBinder(self, shape: TopoDS_Shape, hs: Optional[bool] = True) -> Standard_Transient: ...
	def ShapeType(self, shape: TopoDS_Shape, compound: bool) -> TopAbs_ShapeEnum: ...
	def ShapeValue(self, seqv: TopTools_HSequenceOfShape, num: int) -> TopoDS_Shape: ...
	def SortedCompound(self, shape: TopoDS_Shape, type: TopAbs_ShapeEnum, explore: bool, compound: bool) -> TopoDS_Shape: ...
	def ToAString(self, strcon: str) -> TCollection_AsciiString: ...
	@overload
	def ToCString(self, strval: TCollection_HAsciiString) -> str: ...
	@overload
	def ToCString(self, strval: TCollection_AsciiString) -> str: ...
	@overload
	def ToEString(self, strval: TCollection_HExtendedString) -> Standard_ExtString: ...
	@overload
	def ToEString(self, strval: TCollection_ExtendedString) -> Standard_ExtString: ...
	@overload
	def ToHString(self, strcon: str) -> TCollection_HAsciiString: ...
	@overload
	def ToHString(self, strcon: Standard_ExtString) -> TCollection_HExtendedString: ...
	def ToXString(self, strcon: Standard_ExtString) -> TCollection_ExtendedString: ...
	def TraValue(self, list: Standard_Transient, num: int) -> Standard_Transient: ...
	def TraceLine(self, line: str) -> None: ...
	def TraceLines(self, lines: Standard_Transient) -> None: ...
	def TypeName(self, item: Standard_Transient, nopk: Optional[bool] = False) -> str: ...

class XSControl_Vars(Standard_Transient):
	def __init__(self) -> None: ...
	def Get(self, name: str) -> Standard_Transient: ...
	def GetCurve(self, name: str) -> Geom_Curve: ...
	def GetCurve2d(self, name: str) -> Geom2d_Curve: ...
	def GetGeom(self, name: str) -> Geom_Geometry: ...
	def GetPoint(self, name: str, pnt: gp_Pnt) -> bool: ...
	def GetPoint2d(self, name: str, pnt: gp_Pnt2d) -> bool: ...
	def GetShape(self, name: str) -> TopoDS_Shape: ...
	def GetSurface(self, name: str) -> Geom_Surface: ...
	def Set(self, name: str, val: Standard_Transient) -> None: ...
	def SetPoint(self, name: str, val: gp_Pnt) -> None: ...
	def SetPoint2d(self, name: str, val: gp_Pnt2d) -> None: ...
	def SetShape(self, name: str, val: TopoDS_Shape) -> None: ...

class XSControl_WorkSession(IFSelect_WorkSession):
	def __init__(self) -> None: ...
	def ClearContext(self) -> None: ...
	def ClearData(self, theMode: int) -> None: ...
	def Context(self) -> False: ...
	def InitTransferReader(self, theMode: int) -> None: ...
	def MapReader(self) -> Transfer_TransientProcess: ...
	def NewModel(self) -> Interface_InterfaceModel: ...
	def NormAdaptor(self) -> XSControl_Controller: ...
	def Result(self, theEnt: Standard_Transient, theMode: int) -> Standard_Transient: ...
	def SelectNorm(self, theNormName: str) -> bool: ...
	def SelectedNorm(self, theRsc: Optional[bool] = False) -> str: ...
	def SetController(self, theCtl: XSControl_Controller) -> None: ...
	def SetMapReader(self, theTP: Transfer_TransientProcess) -> bool: ...
	def SetMapWriter(self, theFP: Transfer_FinderProcess) -> bool: ...
	def SetTransferReader(self, theTR: XSControl_TransferReader) -> None: ...
	def SetVars(self, theVars: XSControl_Vars) -> None: ...
	def TransferReadOne(self, theEnts: Standard_Transient, theProgress: Optional[Message_ProgressRange] = Message_ProgressRange()) -> int: ...
	def TransferReadRoots(self, theProgress: Optional[Message_ProgressRange] = Message_ProgressRange()) -> int: ...
	def TransferReader(self) -> XSControl_TransferReader: ...
	def TransferWriteCheckList(self) -> Interface_CheckIterator: ...
	def TransferWriteShape(self, theShape: TopoDS_Shape, theCompGraph: Optional[bool] = True, theProgress: Optional[Message_ProgressRange] = Message_ProgressRange()) -> IFSelect_ReturnStatus: ...
	def TransferWriter(self) -> XSControl_TransferWriter: ...
	def Vars(self) -> XSControl_Vars: ...

class XSControl_Writer:
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, norm: str) -> None: ...
	@overload
	def __init__(self, WS: XSControl_WorkSession, scratch: Optional[bool] = True) -> None: ...
	def Model(self, newone: Optional[bool] = False) -> Interface_InterfaceModel: ...
	def PrintStatsTransfer(self, what: int, mode: Optional[int] = 0) -> None: ...
	def SetNorm(self, norm: str) -> bool: ...
	def SetWS(self, WS: XSControl_WorkSession, scratch: Optional[bool] = True) -> None: ...
	def TransferShape(self, sh: TopoDS_Shape, mode: Optional[int] = 0, theProgress: Optional[Message_ProgressRange] = Message_ProgressRange()) -> IFSelect_ReturnStatus: ...
	def WS(self) -> XSControl_WorkSession: ...
	def WriteFile(self, filename: str) -> IFSelect_ReturnStatus: ...

# harray1 classes
# harray2 classes
# hsequence classes

xscontrol_Session = xscontrol.Session
xscontrol_Vars = xscontrol.Vars
XSControl_ConnectedShapes_AdjacentEntities = XSControl_ConnectedShapes.AdjacentEntities
XSControl_Controller_Recorded = XSControl_Controller.Recorded
XSControl_FuncShape_FileAndVar = XSControl_FuncShape.FileAndVar
XSControl_FuncShape_Init = XSControl_FuncShape.Init
XSControl_FuncShape_MoreShapes = XSControl_FuncShape.MoreShapes
XSControl_Functions_Init = XSControl_Functions.Init
XSControl_TransferReader_PrintStatsOnList = XSControl_TransferReader.PrintStatsOnList
XSControl_TransferReader_PrintStatsProcess = XSControl_TransferReader.PrintStatsProcess



from enum import IntEnum
from typing import overload, NewType, Optional, Tuple

from OCC.Core.Standard import *
from OCC.Core.NCollection import *
from OCC.Core.gp import *
from OCC.Core.Geom import *
from OCC.Core.Geom2d import *
from OCC.Core.StepGeom import *
from OCC.Core.TColgp import *


class GeomToStep_Root:
	def IsDone(self) -> bool: ...

class GeomToStep_MakeAxis1Placement(GeomToStep_Root):
	@overload
	def __init__(self, A: gp_Ax1) -> None: ...
	@overload
	def __init__(self, A: gp_Ax2d) -> None: ...
	@overload
	def __init__(self, A: Geom_Axis1Placement) -> None: ...
	@overload
	def __init__(self, A: Geom2d_AxisPlacement) -> None: ...
	def Value(self) -> StepGeom_Axis1Placement: ...

class GeomToStep_MakeAxis2Placement2d(GeomToStep_Root):
	@overload
	def __init__(self, A: gp_Ax2) -> None: ...
	@overload
	def __init__(self, A: gp_Ax22d) -> None: ...
	def Value(self) -> StepGeom_Axis2Placement2d: ...

class GeomToStep_MakeAxis2Placement3d(GeomToStep_Root):
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, A: gp_Ax2) -> None: ...
	@overload
	def __init__(self, A: gp_Ax3) -> None: ...
	@overload
	def __init__(self, T: gp_Trsf) -> None: ...
	@overload
	def __init__(self, A: Geom_Axis2Placement) -> None: ...
	def Value(self) -> StepGeom_Axis2Placement3d: ...

class GeomToStep_MakeBSplineCurveWithKnots(GeomToStep_Root):
	@overload
	def __init__(self, Bsplin: Geom_BSplineCurve) -> None: ...
	@overload
	def __init__(self, Bsplin: Geom2d_BSplineCurve) -> None: ...
	def Value(self) -> StepGeom_BSplineCurveWithKnots: ...

class GeomToStep_MakeBSplineCurveWithKnotsAndRationalBSplineCurve(GeomToStep_Root):
	@overload
	def __init__(self, Bsplin: Geom_BSplineCurve) -> None: ...
	@overload
	def __init__(self, Bsplin: Geom2d_BSplineCurve) -> None: ...
	def Value(self) -> StepGeom_BSplineCurveWithKnotsAndRationalBSplineCurve: ...

class GeomToStep_MakeBSplineSurfaceWithKnots(GeomToStep_Root):
	def __init__(self, Bsplin: Geom_BSplineSurface) -> None: ...
	def Value(self) -> StepGeom_BSplineSurfaceWithKnots: ...

class GeomToStep_MakeBSplineSurfaceWithKnotsAndRationalBSplineSurface(GeomToStep_Root):
	def __init__(self, Bsplin: Geom_BSplineSurface) -> None: ...
	def Value(self) -> StepGeom_BSplineSurfaceWithKnotsAndRationalBSplineSurface: ...

class GeomToStep_MakeBoundedCurve(GeomToStep_Root):
	@overload
	def __init__(self, C: Geom_BoundedCurve) -> None: ...
	@overload
	def __init__(self, C: Geom2d_BoundedCurve) -> None: ...
	def Value(self) -> StepGeom_BoundedCurve: ...

class GeomToStep_MakeBoundedSurface(GeomToStep_Root):
	def __init__(self, C: Geom_BoundedSurface) -> None: ...
	def Value(self) -> StepGeom_BoundedSurface: ...

class GeomToStep_MakeCartesianPoint(GeomToStep_Root):
	@overload
	def __init__(self, P: gp_Pnt) -> None: ...
	@overload
	def __init__(self, P: gp_Pnt2d) -> None: ...
	@overload
	def __init__(self, P: Geom_CartesianPoint) -> None: ...
	@overload
	def __init__(self, P: Geom2d_CartesianPoint) -> None: ...
	def Value(self) -> StepGeom_CartesianPoint: ...

class GeomToStep_MakeCircle(GeomToStep_Root):
	@overload
	def __init__(self, C: gp_Circ) -> None: ...
	@overload
	def __init__(self, C: Geom_Circle) -> None: ...
	@overload
	def __init__(self, C: Geom2d_Circle) -> None: ...
	def Value(self) -> StepGeom_Circle: ...

class GeomToStep_MakeConic(GeomToStep_Root):
	@overload
	def __init__(self, C: Geom_Conic) -> None: ...
	@overload
	def __init__(self, C: Geom2d_Conic) -> None: ...
	def Value(self) -> StepGeom_Conic: ...

class GeomToStep_MakeConicalSurface(GeomToStep_Root):
	def __init__(self, CSurf: Geom_ConicalSurface) -> None: ...
	def Value(self) -> StepGeom_ConicalSurface: ...

class GeomToStep_MakeCurve(GeomToStep_Root):
	@overload
	def __init__(self, C: Geom_Curve) -> None: ...
	@overload
	def __init__(self, C: Geom2d_Curve) -> None: ...
	def Value(self) -> StepGeom_Curve: ...

class GeomToStep_MakeCylindricalSurface(GeomToStep_Root):
	def __init__(self, CSurf: Geom_CylindricalSurface) -> None: ...
	def Value(self) -> StepGeom_CylindricalSurface: ...

class GeomToStep_MakeDirection(GeomToStep_Root):
	@overload
	def __init__(self, D: gp_Dir) -> None: ...
	@overload
	def __init__(self, D: gp_Dir2d) -> None: ...
	@overload
	def __init__(self, D: Geom_Direction) -> None: ...
	@overload
	def __init__(self, D: Geom2d_Direction) -> None: ...
	def Value(self) -> StepGeom_Direction: ...

class GeomToStep_MakeElementarySurface(GeomToStep_Root):
	def __init__(self, S: Geom_ElementarySurface) -> None: ...
	def Value(self) -> StepGeom_ElementarySurface: ...

class GeomToStep_MakeEllipse(GeomToStep_Root):
	@overload
	def __init__(self, C: gp_Elips) -> None: ...
	@overload
	def __init__(self, C: Geom_Ellipse) -> None: ...
	@overload
	def __init__(self, C: Geom2d_Ellipse) -> None: ...
	def Value(self) -> StepGeom_Ellipse: ...

class GeomToStep_MakeHyperbola(GeomToStep_Root):
	@overload
	def __init__(self, C: Geom2d_Hyperbola) -> None: ...
	@overload
	def __init__(self, C: Geom_Hyperbola) -> None: ...
	def Value(self) -> StepGeom_Hyperbola: ...

class GeomToStep_MakeLine(GeomToStep_Root):
	@overload
	def __init__(self, L: gp_Lin) -> None: ...
	@overload
	def __init__(self, L: gp_Lin2d) -> None: ...
	@overload
	def __init__(self, C: Geom_Line) -> None: ...
	@overload
	def __init__(self, C: Geom2d_Line) -> None: ...
	def Value(self) -> StepGeom_Line: ...

class GeomToStep_MakeParabola(GeomToStep_Root):
	@overload
	def __init__(self, C: Geom2d_Parabola) -> None: ...
	@overload
	def __init__(self, C: Geom_Parabola) -> None: ...
	def Value(self) -> StepGeom_Parabola: ...

class GeomToStep_MakePlane(GeomToStep_Root):
	@overload
	def __init__(self, P: gp_Pln) -> None: ...
	@overload
	def __init__(self, P: Geom_Plane) -> None: ...
	def Value(self) -> StepGeom_Plane: ...

class GeomToStep_MakePolyline(GeomToStep_Root):
	@overload
	def __init__(self, P: TColgp_Array1OfPnt) -> None: ...
	@overload
	def __init__(self, P: TColgp_Array1OfPnt2d) -> None: ...
	def Value(self) -> StepGeom_Polyline: ...

class GeomToStep_MakeRectangularTrimmedSurface(GeomToStep_Root):
	def __init__(self, RTSurf: Geom_RectangularTrimmedSurface) -> None: ...
	def Value(self) -> StepGeom_RectangularTrimmedSurface: ...

class GeomToStep_MakeSphericalSurface(GeomToStep_Root):
	def __init__(self, CSurf: Geom_SphericalSurface) -> None: ...
	def Value(self) -> StepGeom_SphericalSurface: ...

class GeomToStep_MakeSurface(GeomToStep_Root):
	def __init__(self, C: Geom_Surface) -> None: ...
	def Value(self) -> StepGeom_Surface: ...

class GeomToStep_MakeSurfaceOfLinearExtrusion(GeomToStep_Root):
	def __init__(self, CSurf: Geom_SurfaceOfLinearExtrusion) -> None: ...
	def Value(self) -> StepGeom_SurfaceOfLinearExtrusion: ...

class GeomToStep_MakeSurfaceOfRevolution(GeomToStep_Root):
	def __init__(self, RevSurf: Geom_SurfaceOfRevolution) -> None: ...
	def Value(self) -> StepGeom_SurfaceOfRevolution: ...

class GeomToStep_MakeSweptSurface(GeomToStep_Root):
	def __init__(self, S: Geom_SweptSurface) -> None: ...
	def Value(self) -> StepGeom_SweptSurface: ...

class GeomToStep_MakeToroidalSurface(GeomToStep_Root):
	def __init__(self, TorSurf: Geom_ToroidalSurface) -> None: ...
	def Value(self) -> StepGeom_ToroidalSurface: ...

class GeomToStep_MakeVector(GeomToStep_Root):
	@overload
	def __init__(self, V: gp_Vec) -> None: ...
	@overload
	def __init__(self, V: gp_Vec2d) -> None: ...
	@overload
	def __init__(self, V: Geom_Vector) -> None: ...
	@overload
	def __init__(self, V: Geom2d_Vector) -> None: ...
	def Value(self) -> StepGeom_Vector: ...

# harray1 classes
# harray2 classes
# hsequence classes




# This file was automatically generated by SWIG (http://www.swig.org).
# Version 4.0.2
#
# Do not make changes to this file unless you know what you are doing--modify
# the SWIG interface file instead.

"""
FilletSurf module, see official documentation at
https://www.opencascade.com/doc/occt-7.4.0/refman/html/package_filletsurf.html
"""

from sys import version_info as _swig_python_version_info
if _swig_python_version_info < (2, 7, 0):
    raise RuntimeError("Python 2.7 or later required")

# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _FilletSurf
else:
    import _FilletSurf

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "thisown":
            self.this.own(value)
        elif name == "this":
            set(self, name, value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


class SwigPyIterator(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr
    __swig_destroy__ = _FilletSurf.delete_SwigPyIterator

    def value(self) -> "PyObject *":
        return _FilletSurf.SwigPyIterator_value(self)

    def incr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _FilletSurf.SwigPyIterator_incr(self, n)

    def decr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _FilletSurf.SwigPyIterator_decr(self, n)

    def distance(self, x: "SwigPyIterator") -> "ptrdiff_t":
        return _FilletSurf.SwigPyIterator_distance(self, x)

    def equal(self, x: "SwigPyIterator") -> "bool":
        return _FilletSurf.SwigPyIterator_equal(self, x)

    def copy(self) -> "swig::SwigPyIterator *":
        return _FilletSurf.SwigPyIterator_copy(self)

    def next(self) -> "PyObject *":
        return _FilletSurf.SwigPyIterator_next(self)

    def __next__(self) -> "PyObject *":
        return _FilletSurf.SwigPyIterator___next__(self)

    def previous(self) -> "PyObject *":
        return _FilletSurf.SwigPyIterator_previous(self)

    def advance(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _FilletSurf.SwigPyIterator_advance(self, n)

    def __eq__(self, x: "SwigPyIterator") -> "bool":
        return _FilletSurf.SwigPyIterator___eq__(self, x)

    def __ne__(self, x: "SwigPyIterator") -> "bool":
        return _FilletSurf.SwigPyIterator___ne__(self, x)

    def __iadd__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _FilletSurf.SwigPyIterator___iadd__(self, n)

    def __isub__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _FilletSurf.SwigPyIterator___isub__(self, n)

    def __add__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _FilletSurf.SwigPyIterator___add__(self, n)

    def __sub__(self, *args) -> "ptrdiff_t":
        return _FilletSurf.SwigPyIterator___sub__(self, *args)
    def __iter__(self):
        return self

# Register SwigPyIterator in _FilletSurf:
_FilletSurf.SwigPyIterator_swigregister(SwigPyIterator)


def _dumps_object(klass):
    """ Overwrite default string output for any wrapped object.
    By default, __repr__ method returns something like:
    <OCC.Core.TopoDS.TopoDS_Shape; proxy of <Swig Object of type 'TopoDS_Shape *' at 0x02BB0758> >
    This is too much verbose.
    We prefer :
    <class 'gp_Pnt'>
    or
    <class 'TopoDS_Shape'>
    """
    klass_name = str(klass.__class__).split(".")[3].split("'")[0]
    repr_string = "<class '" + klass_name + "'"
# for TopoDS_Shape, we also look for the base type
    if klass_name == "TopoDS_Shape":
        if klass.IsNull():
            repr_string += ": Null>"
            return repr_string
        st = klass.ShapeType()
        types = {OCC.Core.TopAbs.TopAbs_VERTEX: "Vertex",
                 OCC.Core.TopAbs.TopAbs_SOLID: "Solid",
                 OCC.Core.TopAbs.TopAbs_EDGE: "Edge",
                 OCC.Core.TopAbs.TopAbs_FACE: "Face",
                 OCC.Core.TopAbs.TopAbs_SHELL: "Shell",
                 OCC.Core.TopAbs.TopAbs_WIRE: "Wire",
                 OCC.Core.TopAbs.TopAbs_COMPOUND: "Compound",
                 OCC.Core.TopAbs.TopAbs_COMPSOLID: "Compsolid"}
        repr_string += "; Type:%s" % types[st]        
    elif hasattr(klass, "IsNull"):
        if klass.IsNull():
            repr_string += "; Null"
    repr_string += ">"
    return repr_string


def process_exception(error: "Standard_Failure", method_name: "std::string", class_name: "std::string") -> "void":
    return _FilletSurf.process_exception(error, method_name, class_name)

from six import with_metaclass
import warnings
from OCC.Wrapper.wrapper_utils import Proxy, deprecated

import OCC.Core.Standard
import OCC.Core.NCollection
import OCC.Core.TopoDS
import OCC.Core.Message
import OCC.Core.TCollection
import OCC.Core.OSD
import OCC.Core.TColStd
import OCC.Core.TopAbs
import OCC.Core.TopLoc
import OCC.Core.gp
import OCC.Core.TopTools
import OCC.Core.Geom
import OCC.Core.GeomAbs
import OCC.Core.TColgp
import OCC.Core.Geom2d
import OCC.Core.ChFi3d
import OCC.Core.BRepAdaptor
import OCC.Core.Adaptor3d
import OCC.Core.Adaptor2d
import OCC.Core.math
import OCC.Core.GeomAdaptor
import OCC.Core.Geom2dAdaptor
import OCC.Core.ChFiDS
import OCC.Core.Law
import OCC.Core.TopOpeBRepBuild
import OCC.Core.TopOpeBRepDS
import OCC.Core.TopOpeBRepTool
import OCC.Core.BRepClass3d
import OCC.Core.IntCurveSurface
import OCC.Core.Intf
import OCC.Core.Bnd
import OCC.Core.BVH
import OCC.Core.IntSurf
import OCC.Core.IntCurvesFace
import OCC.Core.TopExp
import OCC.Core.Extrema
import OCC.Core.BRepBlend
import OCC.Core.BlendFunc
import OCC.Core.Convert
import OCC.Core.Blend
import OCC.Core.Approx
import OCC.Core.AppCont
import OCC.Core.AppParCurves
import OCC.Core.AppBlend
import OCC.Core.GeomFill
import OCC.Core.TColGeom

from enum import IntEnum
from OCC.Core.Exception import *

FilletSurf_IsOk = _FilletSurf.FilletSurf_IsOk
FilletSurf_IsNotOk = _FilletSurf.FilletSurf_IsNotOk
FilletSurf_IsPartial = _FilletSurf.FilletSurf_IsPartial
FilletSurf_TwoExtremityOnEdge = _FilletSurf.FilletSurf_TwoExtremityOnEdge
FilletSurf_OneExtremityOnEdge = _FilletSurf.FilletSurf_OneExtremityOnEdge
FilletSurf_NoExtremityOnEdge = _FilletSurf.FilletSurf_NoExtremityOnEdge
FilletSurf_EmptyList = _FilletSurf.FilletSurf_EmptyList
FilletSurf_EdgeNotG1 = _FilletSurf.FilletSurf_EdgeNotG1
FilletSurf_FacesNotG1 = _FilletSurf.FilletSurf_FacesNotG1
FilletSurf_EdgeNotOnShape = _FilletSurf.FilletSurf_EdgeNotOnShape
FilletSurf_NotSharpEdge = _FilletSurf.FilletSurf_NotSharpEdge
FilletSurf_PbFilletCompute = _FilletSurf.FilletSurf_PbFilletCompute


class FilletSurf_StatusDone(IntEnum):
	FilletSurf_IsOk = 0
	FilletSurf_IsNotOk = 1
	FilletSurf_IsPartial = 2
FilletSurf_IsOk = FilletSurf_StatusDone.FilletSurf_IsOk
FilletSurf_IsNotOk = FilletSurf_StatusDone.FilletSurf_IsNotOk
FilletSurf_IsPartial = FilletSurf_StatusDone.FilletSurf_IsPartial

class FilletSurf_StatusType(IntEnum):
	FilletSurf_TwoExtremityOnEdge = 0
	FilletSurf_OneExtremityOnEdge = 1
	FilletSurf_NoExtremityOnEdge = 2
FilletSurf_TwoExtremityOnEdge = FilletSurf_StatusType.FilletSurf_TwoExtremityOnEdge
FilletSurf_OneExtremityOnEdge = FilletSurf_StatusType.FilletSurf_OneExtremityOnEdge
FilletSurf_NoExtremityOnEdge = FilletSurf_StatusType.FilletSurf_NoExtremityOnEdge

class FilletSurf_ErrorTypeStatus(IntEnum):
	FilletSurf_EmptyList = 0
	FilletSurf_EdgeNotG1 = 1
	FilletSurf_FacesNotG1 = 2
	FilletSurf_EdgeNotOnShape = 3
	FilletSurf_NotSharpEdge = 4
	FilletSurf_PbFilletCompute = 5
FilletSurf_EmptyList = FilletSurf_ErrorTypeStatus.FilletSurf_EmptyList
FilletSurf_EdgeNotG1 = FilletSurf_ErrorTypeStatus.FilletSurf_EdgeNotG1
FilletSurf_FacesNotG1 = FilletSurf_ErrorTypeStatus.FilletSurf_FacesNotG1
FilletSurf_EdgeNotOnShape = FilletSurf_ErrorTypeStatus.FilletSurf_EdgeNotOnShape
FilletSurf_NotSharpEdge = FilletSurf_ErrorTypeStatus.FilletSurf_NotSharpEdge
FilletSurf_PbFilletCompute = FilletSurf_ErrorTypeStatus.FilletSurf_PbFilletCompute

class FilletSurf_Builder(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Initialize of the informations necessary for the computation of the fillet on the shape s from a list of edges e and a radius r. //! ta is the angular tolerance tapp3d is the 3d approximation tolerance tapp2d is the 2d approximation tolerance.

        Parameters
        ----------
        S: TopoDS_Shape
        E: TopTools_ListOfShape
        R: float
        Ta: float,optional
        	default value is 1.0e-2
        Tapp3d: float,optional
        	default value is 1.0e-4
        Tapp2d: float,optional
        	default value is 1.0e-5

        Returns
        -------
        None

        """
        _FilletSurf.FilletSurf_Builder_swiginit(self, _FilletSurf.new_FilletSurf_Builder(*args))

    def CurveOnFace1(self, *args) -> "opencascade::handle< Geom_Curve > const &":
        r"""
        Gives the 3d curve of surfacefillet(index) on supportface1(index).

        Parameters
        ----------
        Index: int

        Returns
        -------
        opencascade::handle<Geom_Curve>

        """
        return _FilletSurf.FilletSurf_Builder_CurveOnFace1(self, *args)

    def CurveOnFace2(self, *args) -> "opencascade::handle< Geom_Curve > const &":
        r"""
        Gives the 3d curve of surfacefillet(index) on supportface2(index).

        Parameters
        ----------
        Index: int

        Returns
        -------
        opencascade::handle<Geom_Curve>

        """
        return _FilletSurf.FilletSurf_Builder_CurveOnFace2(self, *args)

    def EndSectionStatus(self, *args) -> "FilletSurf_StatusType":
        r"""
        No available documentation.

        Returns
        -------
        FilletSurf_StatusType

        """
        return _FilletSurf.FilletSurf_Builder_EndSectionStatus(self, *args)

    def FirstParameter(self, *args) -> "Standard_Real":
        r"""
        Gives the parameter of the fillet on the first edge.

        Returns
        -------
        float

        """
        return _FilletSurf.FilletSurf_Builder_FirstParameter(self, *args)

    def IsDone(self, *args) -> "FilletSurf_StatusDone":
        r"""
        Gives the status about the computation of the fillet returns: isok :no problem during the computation isnotok: no result is produced ispartial: the result is partial.

        Returns
        -------
        FilletSurf_StatusDone

        """
        return _FilletSurf.FilletSurf_Builder_IsDone(self, *args)

    def LastParameter(self, *args) -> "Standard_Real":
        r"""
        Gives the parameter of the fillet on the last edge.

        Returns
        -------
        float

        """
        return _FilletSurf.FilletSurf_Builder_LastParameter(self, *args)

    def NbSection(self, *args) -> "Standard_Integer":
        r"""
        No available documentation.

        Parameters
        ----------
        IndexSurf: int

        Returns
        -------
        int

        """
        return _FilletSurf.FilletSurf_Builder_NbSection(self, *args)

    def NbSurface(self, *args) -> "Standard_Integer":
        r"""
        Gives the number of nubs surfaces of the fillet.

        Returns
        -------
        int

        """
        return _FilletSurf.FilletSurf_Builder_NbSurface(self, *args)

    def PCurve1OnFillet(self, *args) -> "opencascade::handle< Geom2d_Curve > const &":
        r"""
        Gives the pcurve associated to curveonface1(index) on the fillet.

        Parameters
        ----------
        Index: int

        Returns
        -------
        opencascade::handle<Geom2d_Curve>

        """
        return _FilletSurf.FilletSurf_Builder_PCurve1OnFillet(self, *args)

    def PCurve2OnFillet(self, *args) -> "opencascade::handle< Geom2d_Curve > const &":
        r"""
        Gives the pcurve associated to curveonsup2(index) on the fillet.

        Parameters
        ----------
        Index: int

        Returns
        -------
        opencascade::handle<Geom2d_Curve>

        """
        return _FilletSurf.FilletSurf_Builder_PCurve2OnFillet(self, *args)

    def PCurveOnFace1(self, *args) -> "opencascade::handle< Geom2d_Curve > const &":
        r"""
        Gives the pcurve associated to curvonsup1(index) on the support face.

        Parameters
        ----------
        Index: int

        Returns
        -------
        opencascade::handle<Geom2d_Curve>

        """
        return _FilletSurf.FilletSurf_Builder_PCurveOnFace1(self, *args)

    def PCurveOnFace2(self, *args) -> "opencascade::handle< Geom2d_Curve > const &":
        r"""
        Gives the pcurve associated to curveonsup2(index) on the support face.

        Parameters
        ----------
        Index: int

        Returns
        -------
        opencascade::handle<Geom2d_Curve>

        """
        return _FilletSurf.FilletSurf_Builder_PCurveOnFace2(self, *args)

    def Perform(self, *args) -> "void":
        r"""
        ---purpose computation of the fillet (list of nubs).

        Returns
        -------
        None

        """
        return _FilletSurf.FilletSurf_Builder_Perform(self, *args)

    def Section(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        IndexSurf: int
        IndexSec: int
        Circ: Geom_TrimmedCurve

        Returns
        -------
        None

        """
        return _FilletSurf.FilletSurf_Builder_Section(self, *args)

    def Simulate(self, *args) -> "void":
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        return _FilletSurf.FilletSurf_Builder_Simulate(self, *args)

    def StartSectionStatus(self, *args) -> "FilletSurf_StatusType":
        r"""
        No available documentation.

        Returns
        -------
        FilletSurf_StatusType

        """
        return _FilletSurf.FilletSurf_Builder_StartSectionStatus(self, *args)

    def StatusError(self, *args) -> "FilletSurf_ErrorTypeStatus":
        r"""
        Gives informations about error status if isdone=isnotok returns edgenotg1: the edges are not g1 facesnotg1 : two connected faces on a same support are not g1 edgenotonshape: the edge is not on shape notsharpedge: the edge is not sharp pbfilletcompute: problem during the computation of the fillet.

        Returns
        -------
        FilletSurf_ErrorTypeStatus

        """
        return _FilletSurf.FilletSurf_Builder_StatusError(self, *args)

    def SupportFace1(self, *args) -> "TopoDS_Face const":
        r"""
        Gives the first support face relative to surfacefillet(index);.

        Parameters
        ----------
        Index: int

        Returns
        -------
        TopoDS_Face

        """
        return _FilletSurf.FilletSurf_Builder_SupportFace1(self, *args)

    def SupportFace2(self, *args) -> "TopoDS_Face const":
        r"""
        Gives the second support face relative to surfacefillet(index);.

        Parameters
        ----------
        Index: int

        Returns
        -------
        TopoDS_Face

        """
        return _FilletSurf.FilletSurf_Builder_SupportFace2(self, *args)

    def SurfaceFillet(self, *args) -> "opencascade::handle< Geom_Surface > const &":
        r"""
        Gives the nubs surface of index index.

        Parameters
        ----------
        Index: int

        Returns
        -------
        opencascade::handle<Geom_Surface>

        """
        return _FilletSurf.FilletSurf_Builder_SurfaceFillet(self, *args)

    def TolApp3d(self, *args) -> "Standard_Real":
        r"""
        Gives the 3d tolerance reached during approximation of surface of index index.

        Parameters
        ----------
        Index: int

        Returns
        -------
        float

        """
        return _FilletSurf.FilletSurf_Builder_TolApp3d(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _FilletSurf.delete_FilletSurf_Builder

# Register FilletSurf_Builder in _FilletSurf:
_FilletSurf.FilletSurf_Builder_swigregister(FilletSurf_Builder)

class FilletSurf_InternalBuilder(OCC.Core.ChFi3d.ChFi3d_FilBuilder):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Parameters
        ----------
        S: TopoDS_Shape
        FShape: ChFi3d_FilletShape,optional
        	default value is ChFi3d_Polynomial
        Ta: float,optional
        	default value is 1.0e-2
        Tapp3d: float,optional
        	default value is 1.0e-4
        Tapp2d: float,optional
        	default value is 1.0e-5

        Returns
        -------
        None

        """
        _FilletSurf.FilletSurf_InternalBuilder_swiginit(self, _FilletSurf.new_FilletSurf_InternalBuilder(*args))

    def Add(self, *args) -> "Standard_Integer":
        r"""
        Initializes the contour with a list of edges 0 : no problem 1 : empty list 2 : the edges are not g1 3 : two connected faces on a same support are not g1 4 : the edge is not on shape 5 : notsharpedge: the edge is not sharp.

        Parameters
        ----------
        E: TopTools_ListOfShape
        R: float

        Returns
        -------
        int

        """
        return _FilletSurf.FilletSurf_InternalBuilder_Add(self, *args)

    def CurveOnFace1(self, *args) -> "opencascade::handle< Geom_Curve > const &":
        r"""
        Gives the 3d curve of surfacefillet(index) on supportface1(index).

        Parameters
        ----------
        Index: int

        Returns
        -------
        opencascade::handle<Geom_Curve>

        """
        return _FilletSurf.FilletSurf_InternalBuilder_CurveOnFace1(self, *args)

    def CurveOnFace2(self, *args) -> "opencascade::handle< Geom_Curve > const &":
        r"""
        Gives the 3d curve of surfacefillet(index) on supportface2(index).

        Parameters
        ----------
        Index: int

        Returns
        -------
        opencascade::handle<Geom_Curve>

        """
        return _FilletSurf.FilletSurf_InternalBuilder_CurveOnFace2(self, *args)

    def Done(self, *args) -> "Standard_Boolean":
        r"""
        No available documentation.

        Returns
        -------
        bool

        """
        return _FilletSurf.FilletSurf_InternalBuilder_Done(self, *args)

    def EndSectionStatus(self, *args) -> "FilletSurf_StatusType":
        r"""
        No available documentation.

        Returns
        -------
        FilletSurf_StatusType

        """
        return _FilletSurf.FilletSurf_InternalBuilder_EndSectionStatus(self, *args)

    def FirstParameter(self, *args) -> "Standard_Real":
        r"""
        Gives the parameter of the fillet on the first edge.

        Returns
        -------
        float

        """
        return _FilletSurf.FilletSurf_InternalBuilder_FirstParameter(self, *args)

    def LastParameter(self, *args) -> "Standard_Real":
        r"""
        Gives the parameter of the fillet on the last edge.

        Returns
        -------
        float

        """
        return _FilletSurf.FilletSurf_InternalBuilder_LastParameter(self, *args)

    def NbSection(self, *args) -> "Standard_Integer":
        r"""
        No available documentation.

        Parameters
        ----------
        IndexSurf: int

        Returns
        -------
        int

        """
        return _FilletSurf.FilletSurf_InternalBuilder_NbSection(self, *args)

    def NbSurface(self, *args) -> "Standard_Integer":
        r"""
        Gives the number of nubs surfaces of the fillet.

        Returns
        -------
        int

        """
        return _FilletSurf.FilletSurf_InternalBuilder_NbSurface(self, *args)

    def PCurve1OnFillet(self, *args) -> "opencascade::handle< Geom2d_Curve > const &":
        r"""
        Gives the pcurve associated to curveonface1(index) on the fillet.

        Parameters
        ----------
        Index: int

        Returns
        -------
        opencascade::handle<Geom2d_Curve>

        """
        return _FilletSurf.FilletSurf_InternalBuilder_PCurve1OnFillet(self, *args)

    def PCurve2OnFillet(self, *args) -> "opencascade::handle< Geom2d_Curve > const &":
        r"""
        Gives the pcurve associated to curveonsup2(index) on the fillet.

        Parameters
        ----------
        Index: int

        Returns
        -------
        opencascade::handle<Geom2d_Curve>

        """
        return _FilletSurf.FilletSurf_InternalBuilder_PCurve2OnFillet(self, *args)

    def PCurveOnFace1(self, *args) -> "opencascade::handle< Geom2d_Curve > const &":
        r"""
        Gives the pcurve associated to curvonsup1(index) on the support face.

        Parameters
        ----------
        Index: int

        Returns
        -------
        opencascade::handle<Geom2d_Curve>

        """
        return _FilletSurf.FilletSurf_InternalBuilder_PCurveOnFace1(self, *args)

    def PCurveOnFace2(self, *args) -> "opencascade::handle< Geom2d_Curve > const &":
        r"""
        Gives the pcurve associated to curveonsup2(index) on the support face.

        Parameters
        ----------
        Index: int

        Returns
        -------
        opencascade::handle<Geom2d_Curve>

        """
        return _FilletSurf.FilletSurf_InternalBuilder_PCurveOnFace2(self, *args)

    def Perform(self, *args) -> "void":
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        return _FilletSurf.FilletSurf_InternalBuilder_Perform(self, *args)

    def Section(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        IndexSurf: int
        IndexSec: int
        Circ: Geom_TrimmedCurve

        Returns
        -------
        None

        """
        return _FilletSurf.FilletSurf_InternalBuilder_Section(self, *args)

    def Simulate(self, *args) -> "void":
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        return _FilletSurf.FilletSurf_InternalBuilder_Simulate(self, *args)

    def StartSectionStatus(self, *args) -> "FilletSurf_StatusType":
        r"""
        No available documentation.

        Returns
        -------
        FilletSurf_StatusType

        """
        return _FilletSurf.FilletSurf_InternalBuilder_StartSectionStatus(self, *args)

    def SupportFace1(self, *args) -> "TopoDS_Face const":
        r"""
        Gives the first support face relative to surfacefillet(index);.

        Parameters
        ----------
        Index: int

        Returns
        -------
        TopoDS_Face

        """
        return _FilletSurf.FilletSurf_InternalBuilder_SupportFace1(self, *args)

    def SupportFace2(self, *args) -> "TopoDS_Face const":
        r"""
        Gives the second support face relative to surfacefillet(index);.

        Parameters
        ----------
        Index: int

        Returns
        -------
        TopoDS_Face

        """
        return _FilletSurf.FilletSurf_InternalBuilder_SupportFace2(self, *args)

    def SurfaceFillet(self, *args) -> "opencascade::handle< Geom_Surface > const &":
        r"""
        Gives the nubs surface of index index.

        Parameters
        ----------
        Index: int

        Returns
        -------
        opencascade::handle<Geom_Surface>

        """
        return _FilletSurf.FilletSurf_InternalBuilder_SurfaceFillet(self, *args)

    def TolApp3d(self, *args) -> "Standard_Real":
        r"""
        Gives the 3d tolerance reached during approximation of the surface of index index.

        Parameters
        ----------
        Index: int

        Returns
        -------
        float

        """
        return _FilletSurf.FilletSurf_InternalBuilder_TolApp3d(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _FilletSurf.delete_FilletSurf_InternalBuilder

# Register FilletSurf_InternalBuilder in _FilletSurf:
_FilletSurf.FilletSurf_InternalBuilder_swigregister(FilletSurf_InternalBuilder)








from enum import IntEnum
from typing import overload, NewType, Optional, Tuple

from OCC.Core.Standard import *
from OCC.Core.NCollection import *
from OCC.Core.TColgp import *
from OCC.Core.TColStd import *
from OCC.Core.gp import *

Convert_SequenceOfArray1OfPoles2d = NewType('Convert_SequenceOfArray1OfPoles2d', TColgp_SequenceOfArray1OfPnt2d)

class Convert_SequenceOfArray1OfPoles:
    def __init__(self) -> None: ...
    def __len__(self) -> int: ...
    def Size(self) -> int: ...
    def Clear(self) -> None: ...
    def First(self) -> False: ...
    def Last(self) -> False: ...
    def Length(self) -> int: ...
    def Append(self, theItem: False) -> False: ...
    def Prepend(self, theItem: False) -> False: ...
    def RemoveFirst(self) -> None: ...
    def Reverse(self) -> None: ...
    def Value(self, theIndex: int) -> False: ...
    def SetValue(self, theIndex: int, theValue: False) -> None: ...

class Convert_ParameterisationType(IntEnum):
	Convert_TgtThetaOver2: int = ...
	Convert_TgtThetaOver2_1: int = ...
	Convert_TgtThetaOver2_2: int = ...
	Convert_TgtThetaOver2_3: int = ...
	Convert_TgtThetaOver2_4: int = ...
	Convert_QuasiAngular: int = ...
	Convert_RationalC1: int = ...
	Convert_Polynomial: int = ...
Convert_TgtThetaOver2 = Convert_ParameterisationType.Convert_TgtThetaOver2
Convert_TgtThetaOver2_1 = Convert_ParameterisationType.Convert_TgtThetaOver2_1
Convert_TgtThetaOver2_2 = Convert_ParameterisationType.Convert_TgtThetaOver2_2
Convert_TgtThetaOver2_3 = Convert_ParameterisationType.Convert_TgtThetaOver2_3
Convert_TgtThetaOver2_4 = Convert_ParameterisationType.Convert_TgtThetaOver2_4
Convert_QuasiAngular = Convert_ParameterisationType.Convert_QuasiAngular
Convert_RationalC1 = Convert_ParameterisationType.Convert_RationalC1
Convert_Polynomial = Convert_ParameterisationType.Convert_Polynomial

class Convert_CompBezierCurves2dToBSplineCurve2d:
	def __init__(self, AngularTolerance: Optional[float] = 1.0e-4) -> None: ...
	def AddCurve(self, Poles: TColgp_Array1OfPnt2d) -> None: ...
	def Degree(self) -> int: ...
	def KnotsAndMults(self, Knots: TColStd_Array1OfReal, Mults: TColStd_Array1OfInteger) -> None: ...
	def NbKnots(self) -> int: ...
	def NbPoles(self) -> int: ...
	def Perform(self) -> None: ...
	def Poles(self, Poles: TColgp_Array1OfPnt2d) -> None: ...

class Convert_CompBezierCurvesToBSplineCurve:
	def __init__(self, AngularTolerance: Optional[float] = 1.0e-4) -> None: ...
	def AddCurve(self, Poles: TColgp_Array1OfPnt) -> None: ...
	def Degree(self) -> int: ...
	def KnotsAndMults(self, Knots: TColStd_Array1OfReal, Mults: TColStd_Array1OfInteger) -> None: ...
	def NbKnots(self) -> int: ...
	def NbPoles(self) -> int: ...
	def Perform(self) -> None: ...
	def Poles(self, Poles: TColgp_Array1OfPnt) -> None: ...

class Convert_CompPolynomialToPoles:
	@overload
	def __init__(self, NumCurves: int, Continuity: int, Dimension: int, MaxDegree: int, NumCoeffPerCurve: TColStd_HArray1OfInteger, Coefficients: TColStd_HArray1OfReal, PolynomialIntervals: TColStd_HArray2OfReal, TrueIntervals: TColStd_HArray1OfReal) -> None: ...
	@overload
	def __init__(self, NumCurves: int, Dimension: int, MaxDegree: int, Continuity: TColStd_Array1OfInteger, NumCoeffPerCurve: TColStd_Array1OfInteger, Coefficients: TColStd_Array1OfReal, PolynomialIntervals: TColStd_Array2OfReal, TrueIntervals: TColStd_Array1OfReal) -> None: ...
	@overload
	def __init__(self, Dimension: int, MaxDegree: int, Degree: int, Coefficients: TColStd_Array1OfReal, PolynomialIntervals: TColStd_Array1OfReal, TrueIntervals: TColStd_Array1OfReal) -> None: ...
	def Degree(self) -> int: ...
	def IsDone(self) -> bool: ...
	def Knots(self, K: TColStd_HArray1OfReal) -> None: ...
	def Multiplicities(self, M: TColStd_HArray1OfInteger) -> None: ...
	def NbKnots(self) -> int: ...
	def NbPoles(self) -> int: ...
	def Poles(self, Poles: TColStd_HArray2OfReal) -> None: ...

class Convert_ConicToBSplineCurve:
	@overload
	def BuildCosAndSin(self, Parametrisation: Convert_ParameterisationType, CosNumerator: TColStd_HArray1OfReal, SinNumerator: TColStd_HArray1OfReal, Denominator: TColStd_HArray1OfReal, Knots: TColStd_HArray1OfReal, Mults: TColStd_HArray1OfInteger) -> int: ...
	@overload
	def BuildCosAndSin(self, Parametrisation: Convert_ParameterisationType, UFirst: float, ULast: float, CosNumerator: TColStd_HArray1OfReal, SinNumerator: TColStd_HArray1OfReal, Denominator: TColStd_HArray1OfReal, Knots: TColStd_HArray1OfReal, Mults: TColStd_HArray1OfInteger) -> int: ...
	def Degree(self) -> int: ...
	def IsPeriodic(self) -> bool: ...
	def Knot(self, Index: int) -> float: ...
	def Multiplicity(self, Index: int) -> int: ...
	def NbKnots(self) -> int: ...
	def NbPoles(self) -> int: ...
	def Pole(self, Index: int) -> gp_Pnt2d: ...
	def Weight(self, Index: int) -> float: ...

class Convert_ElementarySurfaceToBSplineSurface:
	def IsUPeriodic(self) -> bool: ...
	def IsVPeriodic(self) -> bool: ...
	def NbUKnots(self) -> int: ...
	def NbUPoles(self) -> int: ...
	def NbVKnots(self) -> int: ...
	def NbVPoles(self) -> int: ...
	def Pole(self, UIndex: int, VIndex: int) -> gp_Pnt: ...
	def UDegree(self) -> int: ...
	def UKnot(self, UIndex: int) -> float: ...
	def UMultiplicity(self, UIndex: int) -> int: ...
	def VDegree(self) -> int: ...
	def VKnot(self, UIndex: int) -> float: ...
	def VMultiplicity(self, VIndex: int) -> int: ...
	def Weight(self, UIndex: int, VIndex: int) -> float: ...

class Convert_GridPolynomialToPoles:
	@overload
	def __init__(self, MaxUDegree: int, MaxVDegree: int, NumCoeff: TColStd_HArray1OfInteger, Coefficients: TColStd_HArray1OfReal, PolynomialUIntervals: TColStd_HArray1OfReal, PolynomialVIntervals: TColStd_HArray1OfReal) -> None: ...
	@overload
	def __init__(self, NbUSurfaces: int, NBVSurfaces: int, UContinuity: int, VContinuity: int, MaxUDegree: int, MaxVDegree: int, NumCoeffPerSurface: TColStd_HArray2OfInteger, Coefficients: TColStd_HArray1OfReal, PolynomialUIntervals: TColStd_HArray1OfReal, PolynomialVIntervals: TColStd_HArray1OfReal, TrueUIntervals: TColStd_HArray1OfReal, TrueVIntervals: TColStd_HArray1OfReal) -> None: ...
	def IsDone(self) -> bool: ...
	def NbUKnots(self) -> int: ...
	def NbUPoles(self) -> int: ...
	def NbVKnots(self) -> int: ...
	def NbVPoles(self) -> int: ...
	def Perform(self, UContinuity: int, VContinuity: int, MaxUDegree: int, MaxVDegree: int, NumCoeffPerSurface: TColStd_HArray2OfInteger, Coefficients: TColStd_HArray1OfReal, PolynomialUIntervals: TColStd_HArray1OfReal, PolynomialVIntervals: TColStd_HArray1OfReal, TrueUIntervals: TColStd_HArray1OfReal, TrueVIntervals: TColStd_HArray1OfReal) -> None: ...
	def Poles(self) -> TColgp_HArray2OfPnt: ...
	def UDegree(self) -> int: ...
	def UKnots(self) -> TColStd_HArray1OfReal: ...
	def UMultiplicities(self) -> TColStd_HArray1OfInteger: ...
	def VDegree(self) -> int: ...
	def VKnots(self) -> TColStd_HArray1OfReal: ...
	def VMultiplicities(self) -> TColStd_HArray1OfInteger: ...

class Convert_CircleToBSplineCurve(Convert_ConicToBSplineCurve):
	@overload
	def __init__(self, C: gp_Circ2d, Parameterisation: Optional[Convert_ParameterisationType] = Convert_TgtThetaOver2) -> None: ...
	@overload
	def __init__(self, C: gp_Circ2d, U1: float, U2: float, Parameterisation: Optional[Convert_ParameterisationType] = Convert_TgtThetaOver2) -> None: ...

class Convert_ConeToBSplineSurface(Convert_ElementarySurfaceToBSplineSurface):
	@overload
	def __init__(self, C: gp_Cone, U1: float, U2: float, V1: float, V2: float) -> None: ...
	@overload
	def __init__(self, C: gp_Cone, V1: float, V2: float) -> None: ...

class Convert_CylinderToBSplineSurface(Convert_ElementarySurfaceToBSplineSurface):
	@overload
	def __init__(self, Cyl: gp_Cylinder, U1: float, U2: float, V1: float, V2: float) -> None: ...
	@overload
	def __init__(self, Cyl: gp_Cylinder, V1: float, V2: float) -> None: ...

class Convert_EllipseToBSplineCurve(Convert_ConicToBSplineCurve):
	@overload
	def __init__(self, E: gp_Elips2d, Parameterisation: Optional[Convert_ParameterisationType] = Convert_TgtThetaOver2) -> None: ...
	@overload
	def __init__(self, E: gp_Elips2d, U1: float, U2: float, Parameterisation: Optional[Convert_ParameterisationType] = Convert_TgtThetaOver2) -> None: ...

class Convert_HyperbolaToBSplineCurve(Convert_ConicToBSplineCurve):
	def __init__(self, H: gp_Hypr2d, U1: float, U2: float) -> None: ...

class Convert_ParabolaToBSplineCurve(Convert_ConicToBSplineCurve):
	def __init__(self, Prb: gp_Parab2d, U1: float, U2: float) -> None: ...

class Convert_SphereToBSplineSurface(Convert_ElementarySurfaceToBSplineSurface):
	@overload
	def __init__(self, Sph: gp_Sphere, U1: float, U2: float, V1: float, V2: float) -> None: ...
	@overload
	def __init__(self, Sph: gp_Sphere, Param1: float, Param2: float, UTrim: Optional[bool] = True) -> None: ...
	@overload
	def __init__(self, Sph: gp_Sphere) -> None: ...

class Convert_TorusToBSplineSurface(Convert_ElementarySurfaceToBSplineSurface):
	@overload
	def __init__(self, T: gp_Torus, U1: float, U2: float, V1: float, V2: float) -> None: ...
	@overload
	def __init__(self, T: gp_Torus, Param1: float, Param2: float, UTrim: Optional[bool] = True) -> None: ...
	@overload
	def __init__(self, T: gp_Torus) -> None: ...

# harray1 classes
# harray2 classes
# hsequence classes




# This file was automatically generated by SWIG (http://www.swig.org).
# Version 4.0.2
#
# Do not make changes to this file unless you know what you are doing--modify
# the SWIG interface file instead.

"""
BRepPrim module, see official documentation at
https://www.opencascade.com/doc/occt-7.4.0/refman/html/package_brepprim.html
"""

from sys import version_info as _swig_python_version_info
if _swig_python_version_info < (2, 7, 0):
    raise RuntimeError("Python 2.7 or later required")

# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _BRepPrim
else:
    import _BRepPrim

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "thisown":
            self.this.own(value)
        elif name == "this":
            set(self, name, value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


class SwigPyIterator(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr
    __swig_destroy__ = _BRepPrim.delete_SwigPyIterator

    def value(self) -> "PyObject *":
        return _BRepPrim.SwigPyIterator_value(self)

    def incr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _BRepPrim.SwigPyIterator_incr(self, n)

    def decr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _BRepPrim.SwigPyIterator_decr(self, n)

    def distance(self, x: "SwigPyIterator") -> "ptrdiff_t":
        return _BRepPrim.SwigPyIterator_distance(self, x)

    def equal(self, x: "SwigPyIterator") -> "bool":
        return _BRepPrim.SwigPyIterator_equal(self, x)

    def copy(self) -> "swig::SwigPyIterator *":
        return _BRepPrim.SwigPyIterator_copy(self)

    def next(self) -> "PyObject *":
        return _BRepPrim.SwigPyIterator_next(self)

    def __next__(self) -> "PyObject *":
        return _BRepPrim.SwigPyIterator___next__(self)

    def previous(self) -> "PyObject *":
        return _BRepPrim.SwigPyIterator_previous(self)

    def advance(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _BRepPrim.SwigPyIterator_advance(self, n)

    def __eq__(self, x: "SwigPyIterator") -> "bool":
        return _BRepPrim.SwigPyIterator___eq__(self, x)

    def __ne__(self, x: "SwigPyIterator") -> "bool":
        return _BRepPrim.SwigPyIterator___ne__(self, x)

    def __iadd__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _BRepPrim.SwigPyIterator___iadd__(self, n)

    def __isub__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _BRepPrim.SwigPyIterator___isub__(self, n)

    def __add__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _BRepPrim.SwigPyIterator___add__(self, n)

    def __sub__(self, *args) -> "ptrdiff_t":
        return _BRepPrim.SwigPyIterator___sub__(self, *args)
    def __iter__(self):
        return self

# Register SwigPyIterator in _BRepPrim:
_BRepPrim.SwigPyIterator_swigregister(SwigPyIterator)


def _dumps_object(klass):
    """ Overwrite default string output for any wrapped object.
    By default, __repr__ method returns something like:
    <OCC.Core.TopoDS.TopoDS_Shape; proxy of <Swig Object of type 'TopoDS_Shape *' at 0x02BB0758> >
    This is too much verbose.
    We prefer :
    <class 'gp_Pnt'>
    or
    <class 'TopoDS_Shape'>
    """
    klass_name = str(klass.__class__).split(".")[3].split("'")[0]
    repr_string = "<class '" + klass_name + "'"
# for TopoDS_Shape, we also look for the base type
    if klass_name == "TopoDS_Shape":
        if klass.IsNull():
            repr_string += ": Null>"
            return repr_string
        st = klass.ShapeType()
        types = {OCC.Core.TopAbs.TopAbs_VERTEX: "Vertex",
                 OCC.Core.TopAbs.TopAbs_SOLID: "Solid",
                 OCC.Core.TopAbs.TopAbs_EDGE: "Edge",
                 OCC.Core.TopAbs.TopAbs_FACE: "Face",
                 OCC.Core.TopAbs.TopAbs_SHELL: "Shell",
                 OCC.Core.TopAbs.TopAbs_WIRE: "Wire",
                 OCC.Core.TopAbs.TopAbs_COMPOUND: "Compound",
                 OCC.Core.TopAbs.TopAbs_COMPSOLID: "Compsolid"}
        repr_string += "; Type:%s" % types[st]        
    elif hasattr(klass, "IsNull"):
        if klass.IsNull():
            repr_string += "; Null"
    repr_string += ">"
    return repr_string


def process_exception(error: "Standard_Failure", method_name: "std::string", class_name: "std::string") -> "void":
    return _BRepPrim.process_exception(error, method_name, class_name)

from six import with_metaclass
import warnings
from OCC.Wrapper.wrapper_utils import Proxy, deprecated

import OCC.Core.Standard
import OCC.Core.NCollection
import OCC.Core.BRep
import OCC.Core.TopoDS
import OCC.Core.Message
import OCC.Core.TCollection
import OCC.Core.OSD
import OCC.Core.TColStd
import OCC.Core.TopAbs
import OCC.Core.TopLoc
import OCC.Core.gp
import OCC.Core.GeomAbs
import OCC.Core.Geom
import OCC.Core.TColgp
import OCC.Core.Poly
import OCC.Core.TShort
import OCC.Core.Geom2d

from enum import IntEnum
from OCC.Core.Exception import *

BRepPrim_XMin = _BRepPrim.BRepPrim_XMin
BRepPrim_XMax = _BRepPrim.BRepPrim_XMax
BRepPrim_YMin = _BRepPrim.BRepPrim_YMin
BRepPrim_YMax = _BRepPrim.BRepPrim_YMax
BRepPrim_ZMin = _BRepPrim.BRepPrim_ZMin
BRepPrim_ZMax = _BRepPrim.BRepPrim_ZMax


class BRepPrim_Direction(IntEnum):
	BRepPrim_XMin = 0
	BRepPrim_XMax = 1
	BRepPrim_YMin = 2
	BRepPrim_YMax = 3
	BRepPrim_ZMin = 4
	BRepPrim_ZMax = 5
BRepPrim_XMin = BRepPrim_Direction.BRepPrim_XMin
BRepPrim_XMax = BRepPrim_Direction.BRepPrim_XMax
BRepPrim_YMin = BRepPrim_Direction.BRepPrim_YMin
BRepPrim_YMax = BRepPrim_Direction.BRepPrim_YMax
BRepPrim_ZMin = BRepPrim_Direction.BRepPrim_ZMin
BRepPrim_ZMax = BRepPrim_Direction.BRepPrim_ZMax

class BRepPrim_Builder(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Creates an empty, useless builder. necesseray for compilation.

        Returns
        -------
        None
        Creates from a builder.

        Parameters
        ----------
        B: BRep_Builder

        Returns
        -------
        None

        """
        _BRepPrim.BRepPrim_Builder_swiginit(self, _BRepPrim.new_BRepPrim_Builder(*args))

    def AddEdgeVertex(self, *args) -> "void":
        r"""
        Adds the vertex <v> in the edge <e>. <p> is the parameter of the vertex on the edge. if direct is false the vertex is reversed.

        Parameters
        ----------
        E: TopoDS_Edge
        V: TopoDS_Vertex
        P: float
        direct: bool

        Returns
        -------
        None
        Adds the vertex <v> in the edge <e>. <p1,p2> are the parameters of the vertex on the closed edge.

        Parameters
        ----------
        E: TopoDS_Edge
        V: TopoDS_Vertex
        P1: float
        P2: float

        Returns
        -------
        None

        """
        return _BRepPrim.BRepPrim_Builder_AddEdgeVertex(self, *args)

    def AddFaceWire(self, *args) -> "void":
        r"""
        Adds the wire <w> in the face <f>.

        Parameters
        ----------
        F: TopoDS_Face
        W: TopoDS_Wire

        Returns
        -------
        None

        """
        return _BRepPrim.BRepPrim_Builder_AddFaceWire(self, *args)

    def AddShellFace(self, *args) -> "void":
        r"""
        Adds the face <f> in the shell <sh>.

        Parameters
        ----------
        Sh: TopoDS_Shell
        F: TopoDS_Face

        Returns
        -------
        None

        """
        return _BRepPrim.BRepPrim_Builder_AddShellFace(self, *args)

    def AddWireEdge(self, *args) -> "void":
        r"""
        Adds the edge <e> in the wire <w>, if direct is false the edge is reversed.

        Parameters
        ----------
        W: TopoDS_Wire
        E: TopoDS_Edge
        direct: bool

        Returns
        -------
        None

        """
        return _BRepPrim.BRepPrim_Builder_AddWireEdge(self, *args)

    def Builder(self, *args) -> "BRep_Builder const &":
        r"""
        No available documentation.

        Returns
        -------
        BRep_Builder

        """
        return _BRepPrim.BRepPrim_Builder_Builder(self, *args)

    def CompleteEdge(self, *args) -> "void":
        r"""
        This is called once an edge is completed. it gives the opportunity to perform any post treatment.

        Parameters
        ----------
        E: TopoDS_Edge

        Returns
        -------
        None

        """
        return _BRepPrim.BRepPrim_Builder_CompleteEdge(self, *args)

    def CompleteFace(self, *args) -> "void":
        r"""
        This is called once a face is completed. it gives the opportunity to perform any post treatment.

        Parameters
        ----------
        F: TopoDS_Face

        Returns
        -------
        None

        """
        return _BRepPrim.BRepPrim_Builder_CompleteFace(self, *args)

    def CompleteShell(self, *args) -> "void":
        r"""
        This is called once a shell is completed. it gives the opportunity to perform any post treatment.

        Parameters
        ----------
        S: TopoDS_Shell

        Returns
        -------
        None

        """
        return _BRepPrim.BRepPrim_Builder_CompleteShell(self, *args)

    def CompleteWire(self, *args) -> "void":
        r"""
        This is called once a wire is completed. it gives the opportunity to perform any post treatment.

        Parameters
        ----------
        W: TopoDS_Wire

        Returns
        -------
        None

        """
        return _BRepPrim.BRepPrim_Builder_CompleteWire(self, *args)

    def MakeDegeneratedEdge(self, *args) -> "void":
        r"""
        Returns in <e> a degenerated edge.

        Parameters
        ----------
        E: TopoDS_Edge

        Returns
        -------
        None

        """
        return _BRepPrim.BRepPrim_Builder_MakeDegeneratedEdge(self, *args)

    def MakeEdge(self, *args) -> "void":
        r"""
        Returns in <e> an edge built with the line equation <l>.

        Parameters
        ----------
        E: TopoDS_Edge
        L: gp_Lin

        Returns
        -------
        None
        Returns in <e> an edge built with the circle equation <c>.

        Parameters
        ----------
        E: TopoDS_Edge
        C: gp_Circ

        Returns
        -------
        None

        """
        return _BRepPrim.BRepPrim_Builder_MakeEdge(self, *args)

    def MakeFace(self, *args) -> "void":
        r"""
        Returns in <f> a face built with the plane equation <p>. used by all primitives.

        Parameters
        ----------
        F: TopoDS_Face
        P: gp_Pln

        Returns
        -------
        None

        """
        return _BRepPrim.BRepPrim_Builder_MakeFace(self, *args)

    def MakeShell(self, *args) -> "void":
        r"""
        Make a empty shell.

        Parameters
        ----------
        S: TopoDS_Shell

        Returns
        -------
        None

        """
        return _BRepPrim.BRepPrim_Builder_MakeShell(self, *args)

    def MakeVertex(self, *args) -> "void":
        r"""
        Returns in <v> a vertex built with the point <p>.

        Parameters
        ----------
        V: TopoDS_Vertex
        P: gp_Pnt

        Returns
        -------
        None

        """
        return _BRepPrim.BRepPrim_Builder_MakeVertex(self, *args)

    def MakeWire(self, *args) -> "void":
        r"""
        Returns in <w> an empty wire.

        Parameters
        ----------
        W: TopoDS_Wire

        Returns
        -------
        None

        """
        return _BRepPrim.BRepPrim_Builder_MakeWire(self, *args)

    def ReverseFace(self, *args) -> "void":
        r"""
        Reverses the face <f>.

        Parameters
        ----------
        F: TopoDS_Face

        Returns
        -------
        None

        """
        return _BRepPrim.BRepPrim_Builder_ReverseFace(self, *args)

    def SetPCurve(self, *args) -> "void":
        r"""
        Sets the line <l> to be the curve representing the edge <e> in the parametric space of the surface of <f>.

        Parameters
        ----------
        E: TopoDS_Edge
        F: TopoDS_Face
        L: gp_Lin2d

        Returns
        -------
        None
        Sets the lines <l1,l2> to be the curves representing the edge <e> in the parametric space of the closed surface of <f>.

        Parameters
        ----------
        E: TopoDS_Edge
        F: TopoDS_Face
        L1: gp_Lin2d
        L2: gp_Lin2d

        Returns
        -------
        None
        Sets the circle <c> to be the curve representing the edge <e> in the parametric space of the surface of <f>.

        Parameters
        ----------
        E: TopoDS_Edge
        F: TopoDS_Face
        C: gp_Circ2d

        Returns
        -------
        None

        """
        return _BRepPrim.BRepPrim_Builder_SetPCurve(self, *args)

    def SetParameters(self, *args) -> "void":
        r"""
        <p1,p2> are the parameters of the vertex on the edge. the edge is a closed curve.

        Parameters
        ----------
        E: TopoDS_Edge
        V: TopoDS_Vertex
        P1: float
        P2: float

        Returns
        -------
        None

        """
        return _BRepPrim.BRepPrim_Builder_SetParameters(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _BRepPrim.delete_BRepPrim_Builder

# Register BRepPrim_Builder in _BRepPrim:
_BRepPrim.BRepPrim_Builder_swigregister(BRepPrim_Builder)

class BRepPrim_FaceBuilder(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None
        No available documentation.

        Parameters
        ----------
        B: BRep_Builder
        S: Geom_Surface

        Returns
        -------
        None
        No available documentation.

        Parameters
        ----------
        B: BRep_Builder
        S: Geom_Surface
        UMin: float
        UMax: float
        VMin: float
        VMax: float

        Returns
        -------
        None

        """
        _BRepPrim.BRepPrim_FaceBuilder_swiginit(self, _BRepPrim.new_BRepPrim_FaceBuilder(*args))

    def Edge(self, *args) -> "TopoDS_Edge const":
        r"""
        Returns the edge of index <i> 1 - edge vmin 2 - edge umax 3 - edge vmax 4 - edge umin.

        Parameters
        ----------
        I: int

        Returns
        -------
        TopoDS_Edge

        """
        return _BRepPrim.BRepPrim_FaceBuilder_Edge(self, *args)

    def Face(self, *args) -> "TopoDS_Face const":
        r"""
        No available documentation.

        Returns
        -------
        TopoDS_Face

        """
        return _BRepPrim.BRepPrim_FaceBuilder_Face(self, *args)

    def Init(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        B: BRep_Builder
        S: Geom_Surface

        Returns
        -------
        None
        No available documentation.

        Parameters
        ----------
        B: BRep_Builder
        S: Geom_Surface
        UMin: float
        UMax: float
        VMin: float
        VMax: float

        Returns
        -------
        None

        """
        return _BRepPrim.BRepPrim_FaceBuilder_Init(self, *args)

    def Vertex(self, *args) -> "TopoDS_Vertex const":
        r"""
        Returns the vertex of index <i> 1 - vertex umin,vmin 2 - vertex umax,vmin 3 - vertex umax,vmax 4 - vertex umin,vmax.

        Parameters
        ----------
        I: int

        Returns
        -------
        TopoDS_Vertex

        """
        return _BRepPrim.BRepPrim_FaceBuilder_Vertex(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _BRepPrim.delete_BRepPrim_FaceBuilder

# Register BRepPrim_FaceBuilder in _BRepPrim:
_BRepPrim.BRepPrim_FaceBuilder_swigregister(BRepPrim_FaceBuilder)

class BRepPrim_GWedge(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Default constructor.

        Returns
        -------
        None
        Creates a gwedge algorithm. <axes> is the axis system for the primitive. //! xmin, ymin, zmin are set to 0 xmax, ymax, zmax are set to dx, dy, dz z2min = zmin z2max = zmax x2min = xmin x2max = xmax the result is a box dx,dy,dz should be positive.

        Parameters
        ----------
        B: BRepPrim_Builder
        Axes: gp_Ax2
        dx: float
        dy: float
        dz: float

        Returns
        -------
        None
        Creates a gwedge primitive. <axes> is the axis system for the primitive. //! xmin, ymin, zmin are set to 0 xmax, ymax, zmax are set to dx, dy, dz z2min = zmin z2max = zmax x2min = ltx x2max = ltx the result is a step right angular wedge dx,dy,dz should be positive ltx should not be negative.

        Parameters
        ----------
        B: BRepPrim_Builder
        Axes: gp_Ax2
        dx: float
        dy: float
        dz: float
        ltx: float

        Returns
        -------
        None
        Create a gwedge primitive. <axes> is the axis system for the primitive. //! all the fields are set to the corresponding value xyzmax - xyzmin should be positive zx2max - zx2min should not be negative.

        Parameters
        ----------
        B: BRepPrim_Builder
        Axes: gp_Ax2
        xmin: float
        ymin: float
        zmin: float
        z2min: float
        x2min: float
        xmax: float
        ymax: float
        zmax: float
        z2max: float
        x2max: float

        Returns
        -------
        None

        """
        _BRepPrim.BRepPrim_GWedge_swiginit(self, _BRepPrim.new_BRepPrim_GWedge(*args))

    def Axes(self, *args) -> "gp_Ax2":
        r"""
        Returns the coordinates system from <self>.

        Returns
        -------
        gp_Ax2

        """
        return _BRepPrim.BRepPrim_GWedge_Axes(self, *args)

    def Close(self, *args) -> "void":
        r"""
        Closes <self> in <d1> direction. a face and its edges or vertices are said existant.

        Parameters
        ----------
        d1: BRepPrim_Direction

        Returns
        -------
        None

        """
        return _BRepPrim.BRepPrim_GWedge_Close(self, *args)

    def Edge(self, *args) -> "TopoDS_Edge const":
        r"""
        Returns the edge of <self> located in <d1><d2> direction.

        Parameters
        ----------
        d1: BRepPrim_Direction
        d2: BRepPrim_Direction

        Returns
        -------
        TopoDS_Edge

        """
        return _BRepPrim.BRepPrim_GWedge_Edge(self, *args)

    def Face(self, *args) -> "TopoDS_Face const":
        r"""
        Returns the face of <self> located in <d1> direction.

        Parameters
        ----------
        d1: BRepPrim_Direction

        Returns
        -------
        TopoDS_Face

        """
        return _BRepPrim.BRepPrim_GWedge_Face(self, *args)

    def GetX2Max(self, *args) -> "Standard_Real":
        r"""
        Returns x2max value from <self>.

        Returns
        -------
        float

        """
        return _BRepPrim.BRepPrim_GWedge_GetX2Max(self, *args)

    def GetX2Min(self, *args) -> "Standard_Real":
        r"""
        Returns x2min value from <self>.

        Returns
        -------
        float

        """
        return _BRepPrim.BRepPrim_GWedge_GetX2Min(self, *args)

    def GetXMax(self, *args) -> "Standard_Real":
        r"""
        Returns xmax value from <self>.

        Returns
        -------
        float

        """
        return _BRepPrim.BRepPrim_GWedge_GetXMax(self, *args)

    def GetXMin(self, *args) -> "Standard_Real":
        r"""
        Returns xmin value from <self>.

        Returns
        -------
        float

        """
        return _BRepPrim.BRepPrim_GWedge_GetXMin(self, *args)

    def GetYMax(self, *args) -> "Standard_Real":
        r"""
        Returns ymax value from <self>.

        Returns
        -------
        float

        """
        return _BRepPrim.BRepPrim_GWedge_GetYMax(self, *args)

    def GetYMin(self, *args) -> "Standard_Real":
        r"""
        Returns ymin value from <self>.

        Returns
        -------
        float

        """
        return _BRepPrim.BRepPrim_GWedge_GetYMin(self, *args)

    def GetZ2Max(self, *args) -> "Standard_Real":
        r"""
        Returns z2max value from <self>.

        Returns
        -------
        float

        """
        return _BRepPrim.BRepPrim_GWedge_GetZ2Max(self, *args)

    def GetZ2Min(self, *args) -> "Standard_Real":
        r"""
        Returns z2min value from <self>.

        Returns
        -------
        float

        """
        return _BRepPrim.BRepPrim_GWedge_GetZ2Min(self, *args)

    def GetZMax(self, *args) -> "Standard_Real":
        r"""
        Returns zmax value from <self>.

        Returns
        -------
        float

        """
        return _BRepPrim.BRepPrim_GWedge_GetZMax(self, *args)

    def GetZMin(self, *args) -> "Standard_Real":
        r"""
        Returns zmin value from <self>.

        Returns
        -------
        float

        """
        return _BRepPrim.BRepPrim_GWedge_GetZMin(self, *args)

    def HasEdge(self, *args) -> "Standard_Boolean":
        r"""
        Returns true if <self> has an edge in <d1><d2> direction.

        Parameters
        ----------
        d1: BRepPrim_Direction
        d2: BRepPrim_Direction

        Returns
        -------
        bool

        """
        return _BRepPrim.BRepPrim_GWedge_HasEdge(self, *args)

    def HasFace(self, *args) -> "Standard_Boolean":
        r"""
        Returns true if <self> has a face in <d1> direction.

        Parameters
        ----------
        d1: BRepPrim_Direction

        Returns
        -------
        bool

        """
        return _BRepPrim.BRepPrim_GWedge_HasFace(self, *args)

    def HasVertex(self, *args) -> "Standard_Boolean":
        r"""
        Returns true if <self> has a vertex in <d1><d2><d3> direction.

        Parameters
        ----------
        d1: BRepPrim_Direction
        d2: BRepPrim_Direction
        d3: BRepPrim_Direction

        Returns
        -------
        bool

        """
        return _BRepPrim.BRepPrim_GWedge_HasVertex(self, *args)

    def HasWire(self, *args) -> "Standard_Boolean":
        r"""
        Returns true if <self> has a wire in <d1> direction.

        Parameters
        ----------
        d1: BRepPrim_Direction

        Returns
        -------
        bool

        """
        return _BRepPrim.BRepPrim_GWedge_HasWire(self, *args)

    def IsDegeneratedShape(self, *args) -> "Standard_Boolean":
        r"""
        Checkes a shape on degeneracy returns true if a shape is degenerated.

        Returns
        -------
        bool

        """
        return _BRepPrim.BRepPrim_GWedge_IsDegeneratedShape(self, *args)

    def IsInfinite(self, *args) -> "Standard_Boolean":
        r"""
        Returns true if <self> is open in <d1> direction.

        Parameters
        ----------
        d1: BRepPrim_Direction

        Returns
        -------
        bool

        """
        return _BRepPrim.BRepPrim_GWedge_IsInfinite(self, *args)

    def Line(self, *args) -> "gp_Lin":
        r"""
        Returns the line of the edge of <self> located in <d1><d2> direction.

        Parameters
        ----------
        d1: BRepPrim_Direction
        d2: BRepPrim_Direction

        Returns
        -------
        gp_Lin

        """
        return _BRepPrim.BRepPrim_GWedge_Line(self, *args)

    def Open(self, *args) -> "void":
        r"""
        Opens <self> in <d1> direction. a face and its edges or vertices are said nonexistant.

        Parameters
        ----------
        d1: BRepPrim_Direction

        Returns
        -------
        None

        """
        return _BRepPrim.BRepPrim_GWedge_Open(self, *args)

    def Plane(self, *args) -> "gp_Pln":
        r"""
        Returns the plane of the face of <self> located in <d1> direction.

        Parameters
        ----------
        d1: BRepPrim_Direction

        Returns
        -------
        gp_Pln

        """
        return _BRepPrim.BRepPrim_GWedge_Plane(self, *args)

    def Point(self, *args) -> "gp_Pnt":
        r"""
        Returns the point of the vertex of <self> located in <d1><d2><d3> direction.

        Parameters
        ----------
        d1: BRepPrim_Direction
        d2: BRepPrim_Direction
        d3: BRepPrim_Direction

        Returns
        -------
        gp_Pnt

        """
        return _BRepPrim.BRepPrim_GWedge_Point(self, *args)

    def Shell(self, *args) -> "TopoDS_Shell const":
        r"""
        Returns the shell containing the faces of <self>.

        Returns
        -------
        TopoDS_Shell

        """
        return _BRepPrim.BRepPrim_GWedge_Shell(self, *args)

    def Vertex(self, *args) -> "TopoDS_Vertex const":
        r"""
        Returns the vertex of <self> located in <d1><d2><d3> direction.

        Parameters
        ----------
        d1: BRepPrim_Direction
        d2: BRepPrim_Direction
        d3: BRepPrim_Direction

        Returns
        -------
        TopoDS_Vertex

        """
        return _BRepPrim.BRepPrim_GWedge_Vertex(self, *args)

    def Wire(self, *args) -> "TopoDS_Wire const":
        r"""
        Returns the wire of <self> located in <d1> direction.

        Parameters
        ----------
        d1: BRepPrim_Direction

        Returns
        -------
        TopoDS_Wire

        """
        return _BRepPrim.BRepPrim_GWedge_Wire(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _BRepPrim.delete_BRepPrim_GWedge

# Register BRepPrim_GWedge in _BRepPrim:
_BRepPrim.BRepPrim_GWedge_swigregister(BRepPrim_GWedge)

class BRepPrim_OneAxis(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    def Angle(self, *args) -> "void":
        r"""
        No available documentation.

        Returns
        -------
        float
        No available documentation.

        Parameters
        ----------
        A: float

        Returns
        -------
        None

        """
        return _BRepPrim.BRepPrim_OneAxis_Angle(self, *args)

    def Axes(self, *args) -> "void":
        r"""
        Returns the ax2 from <self>.

        Returns
        -------
        gp_Ax2
        No available documentation.

        Parameters
        ----------
        A: gp_Ax2

        Returns
        -------
        None

        """
        return _BRepPrim.BRepPrim_OneAxis_Axes(self, *args)

    def AxisBottomVertex(self, *args) -> "TopoDS_Vertex const":
        r"""
        Returns the vertex at the bottom altitude on the axis.

        Returns
        -------
        TopoDS_Vertex

        """
        return _BRepPrim.BRepPrim_OneAxis_AxisBottomVertex(self, *args)

    def AxisEdge(self, *args) -> "TopoDS_Edge const":
        r"""
        Returns the edge built along the axis and oriented on +z of the axis.

        Returns
        -------
        TopoDS_Edge

        """
        return _BRepPrim.BRepPrim_OneAxis_AxisEdge(self, *args)

    def AxisEndWire(self, *args) -> "TopoDS_Wire const":
        r"""
        Returns the wire in the end face with the axisedge.

        Returns
        -------
        TopoDS_Wire

        """
        return _BRepPrim.BRepPrim_OneAxis_AxisEndWire(self, *args)

    def AxisStartWire(self, *args) -> "TopoDS_Wire const":
        r"""
        Returns the wire in the start face with the axisedge.

        Returns
        -------
        TopoDS_Wire

        """
        return _BRepPrim.BRepPrim_OneAxis_AxisStartWire(self, *args)

    def AxisTopVertex(self, *args) -> "TopoDS_Vertex const":
        r"""
        Returns the vertex at the top altitude on the axis.

        Returns
        -------
        TopoDS_Vertex

        """
        return _BRepPrim.BRepPrim_OneAxis_AxisTopVertex(self, *args)

    def BottomEdge(self, *args) -> "TopoDS_Edge const":
        r"""
        Returns the edge at vmin. if meridianclosed() the topedge and the bottomedge are the same edge.

        Returns
        -------
        TopoDS_Edge

        """
        return _BRepPrim.BRepPrim_OneAxis_BottomEdge(self, *args)

    def BottomEndVertex(self, *args) -> "TopoDS_Vertex const":
        r"""
        Returns the vertex (angle,vmax).

        Returns
        -------
        TopoDS_Vertex

        """
        return _BRepPrim.BRepPrim_OneAxis_BottomEndVertex(self, *args)

    def BottomFace(self, *args) -> "TopoDS_Face const":
        r"""
        Returns the bottom planar face. it is oriented toward the -z axis (outside).

        Returns
        -------
        TopoDS_Face

        """
        return _BRepPrim.BRepPrim_OneAxis_BottomFace(self, *args)

    def BottomStartVertex(self, *args) -> "TopoDS_Vertex const":
        r"""
        Returns the vertex (0,vmin).

        Returns
        -------
        TopoDS_Vertex

        """
        return _BRepPrim.BRepPrim_OneAxis_BottomStartVertex(self, *args)

    def BottomWire(self, *args) -> "TopoDS_Wire const":
        r"""
        Returns the wire in the bottom face.

        Returns
        -------
        TopoDS_Wire

        """
        return _BRepPrim.BRepPrim_OneAxis_BottomWire(self, *args)

    def EndBottomEdge(self, *args) -> "TopoDS_Edge const":
        r"""
        Returns the linear edge between end face and bottom face.

        Returns
        -------
        TopoDS_Edge

        """
        return _BRepPrim.BRepPrim_OneAxis_EndBottomEdge(self, *args)

    def EndEdge(self, *args) -> "TopoDS_Edge const":
        r"""
        Returns the edge at angle angle. if !hassides() the startedge and the endedge are the same edge.

        Returns
        -------
        TopoDS_Edge

        """
        return _BRepPrim.BRepPrim_OneAxis_EndEdge(self, *args)

    def EndFace(self, *args) -> "TopoDS_Face const":
        r"""
        Returns the face ending the slice, it is oriented toward the exterior of the primitive.

        Returns
        -------
        TopoDS_Face

        """
        return _BRepPrim.BRepPrim_OneAxis_EndFace(self, *args)

    def EndTopEdge(self, *args) -> "TopoDS_Edge const":
        r"""
        Returns the linear edge between end face and top face.

        Returns
        -------
        TopoDS_Edge

        """
        return _BRepPrim.BRepPrim_OneAxis_EndTopEdge(self, *args)

    def EndWire(self, *args) -> "TopoDS_Wire const":
        r"""
        Returns the wire in the end face.

        Returns
        -------
        TopoDS_Wire

        """
        return _BRepPrim.BRepPrim_OneAxis_EndWire(self, *args)

    def HasBottom(self, *args) -> "Standard_Boolean":
        r"""
        Returns true if there is a bottom face. //! that is neither : vmininfinite() meridianclosed() meridianonaxis(vmin).

        Returns
        -------
        bool

        """
        return _BRepPrim.BRepPrim_OneAxis_HasBottom(self, *args)

    def HasSides(self, *args) -> "Standard_Boolean":
        r"""
        Returns true if there are start and end faces. //! that is : 2*pi - angle > precision::angular().

        Returns
        -------
        bool

        """
        return _BRepPrim.BRepPrim_OneAxis_HasSides(self, *args)

    def HasTop(self, *args) -> "Standard_Boolean":
        r"""
        Returns true if there is a top face. //! that is neither : vmaxinfinite() meridianclosed() meridianonaxis(vmax).

        Returns
        -------
        bool

        """
        return _BRepPrim.BRepPrim_OneAxis_HasTop(self, *args)

    def LateralEndWire(self, *args) -> "TopoDS_Wire const":
        r"""
        Returns the wire with in lateral face with the end edge.

        Returns
        -------
        TopoDS_Wire

        """
        return _BRepPrim.BRepPrim_OneAxis_LateralEndWire(self, *args)

    def LateralFace(self, *args) -> "TopoDS_Face const":
        r"""
        Returns the lateral face. it is oriented toward the outside of the primitive.

        Returns
        -------
        TopoDS_Face

        """
        return _BRepPrim.BRepPrim_OneAxis_LateralFace(self, *args)

    def LateralStartWire(self, *args) -> "TopoDS_Wire const":
        r"""
        Returns the wire in the lateral face with the start edge.

        Returns
        -------
        TopoDS_Wire

        """
        return _BRepPrim.BRepPrim_OneAxis_LateralStartWire(self, *args)

    def LateralWire(self, *args) -> "TopoDS_Wire const":
        r"""
        Returns the wire in the lateral face.

        Returns
        -------
        TopoDS_Wire

        """
        return _BRepPrim.BRepPrim_OneAxis_LateralWire(self, *args)

    def MakeEmptyLateralFace(self, *args) -> "TopoDS_Face":
        r"""
        Returns a face with no edges. the surface is the lateral surface with normals pointing outward. the u parameter is the angle with the origin on the x axis. the v parameter is the parameter of the meridian.

        Returns
        -------
        TopoDS_Face

        """
        return _BRepPrim.BRepPrim_OneAxis_MakeEmptyLateralFace(self, *args)

    def MakeEmptyMeridianEdge(self, *args) -> "TopoDS_Edge":
        r"""
        Returns an edge with a 3d curve made from the meridian in the xz plane rotated by <ang> around the z-axis. ang may be 0 or myangle.

        Parameters
        ----------
        Ang: float

        Returns
        -------
        TopoDS_Edge

        """
        return _BRepPrim.BRepPrim_OneAxis_MakeEmptyMeridianEdge(self, *args)

    def MeridianClosed(self, *args) -> "Standard_Boolean":
        r"""
        Returns true if the meridian is closed. default implementation  is meridianvalue(vmin).isequal(meridianvalue(vmax), precision::confusion()).

        Returns
        -------
        bool

        """
        return _BRepPrim.BRepPrim_OneAxis_MeridianClosed(self, *args)

    def MeridianOnAxis(self, *args) -> "Standard_Boolean":
        r"""
        Returns true if the point of parameter <v> on the meridian is on the axis. default implementation is abs(meridianvalue(v).x()) < precision::confusion().

        Parameters
        ----------
        V: float

        Returns
        -------
        bool

        """
        return _BRepPrim.BRepPrim_OneAxis_MeridianOnAxis(self, *args)

    def MeridianValue(self, *args) -> "gp_Pnt2d":
        r"""
        Returns the meridian point at parameter <v> in the plane xz.

        Parameters
        ----------
        V: float

        Returns
        -------
        gp_Pnt2d

        """
        return _BRepPrim.BRepPrim_OneAxis_MeridianValue(self, *args)

    def SetMeridianOffset(self, *args) -> "void":
        r"""
        The meridianoffset is added to the parameters on the meridian curve and to the v values of the pcurves. this is used for the sphere for example, to give a range on the meridian edge which is not vmin, vmax.

        Parameters
        ----------
        MeridianOffset: float,optional
        	default value is 0

        Returns
        -------
        None

        """
        return _BRepPrim.BRepPrim_OneAxis_SetMeridianOffset(self, *args)

    def SetMeridianPCurve(self, *args) -> "void":
        r"""
        Sets the parametric curve of the edge <e> in the face <f> to be the 2d representation of the meridian.

        Parameters
        ----------
        E: TopoDS_Edge
        F: TopoDS_Face

        Returns
        -------
        None

        """
        return _BRepPrim.BRepPrim_OneAxis_SetMeridianPCurve(self, *args)

    def Shell(self, *args) -> "TopoDS_Shell const":
        r"""
        Returns the shell containing all the faces of the primitive.

        Returns
        -------
        TopoDS_Shell

        """
        return _BRepPrim.BRepPrim_OneAxis_Shell(self, *args)

    def StartBottomEdge(self, *args) -> "TopoDS_Edge const":
        r"""
        Returns the linear edge between start face and bottom face.

        Returns
        -------
        TopoDS_Edge

        """
        return _BRepPrim.BRepPrim_OneAxis_StartBottomEdge(self, *args)

    def StartEdge(self, *args) -> "TopoDS_Edge const":
        r"""
        Returns the edge at angle 0.

        Returns
        -------
        TopoDS_Edge

        """
        return _BRepPrim.BRepPrim_OneAxis_StartEdge(self, *args)

    def StartFace(self, *args) -> "TopoDS_Face const":
        r"""
        Returns the face starting the slice, it is oriented toward the exterior of the primitive.

        Returns
        -------
        TopoDS_Face

        """
        return _BRepPrim.BRepPrim_OneAxis_StartFace(self, *args)

    def StartTopEdge(self, *args) -> "TopoDS_Edge const":
        r"""
        Returns the linear edge between start face and top face.

        Returns
        -------
        TopoDS_Edge

        """
        return _BRepPrim.BRepPrim_OneAxis_StartTopEdge(self, *args)

    def StartWire(self, *args) -> "TopoDS_Wire const":
        r"""
        Returns the wire in the start face.

        Returns
        -------
        TopoDS_Wire

        """
        return _BRepPrim.BRepPrim_OneAxis_StartWire(self, *args)

    def TopEdge(self, *args) -> "TopoDS_Edge const":
        r"""
        Returns the edge at vmax. if meridianclosed() the topedge and the bottomedge are the same edge.

        Returns
        -------
        TopoDS_Edge

        """
        return _BRepPrim.BRepPrim_OneAxis_TopEdge(self, *args)

    def TopEndVertex(self, *args) -> "TopoDS_Vertex const":
        r"""
        Returns the vertex (angle,vmax).

        Returns
        -------
        TopoDS_Vertex

        """
        return _BRepPrim.BRepPrim_OneAxis_TopEndVertex(self, *args)

    def TopFace(self, *args) -> "TopoDS_Face const":
        r"""
        Returns the top planar face. it is oriented toward the +z axis (outside).

        Returns
        -------
        TopoDS_Face

        """
        return _BRepPrim.BRepPrim_OneAxis_TopFace(self, *args)

    def TopStartVertex(self, *args) -> "TopoDS_Vertex const":
        r"""
        Returns the vertex (0,vmax).

        Returns
        -------
        TopoDS_Vertex

        """
        return _BRepPrim.BRepPrim_OneAxis_TopStartVertex(self, *args)

    def TopWire(self, *args) -> "TopoDS_Wire const":
        r"""
        Returns the wire in the top face.

        Returns
        -------
        TopoDS_Wire

        """
        return _BRepPrim.BRepPrim_OneAxis_TopWire(self, *args)

    def VMax(self, *args) -> "void":
        r"""
        No available documentation.

        Returns
        -------
        float
        No available documentation.

        Parameters
        ----------
        V: float

        Returns
        -------
        None

        """
        return _BRepPrim.BRepPrim_OneAxis_VMax(self, *args)

    def VMaxInfinite(self, *args) -> "Standard_Boolean":
        r"""
        Returns true if vmax is infinite. default precision::ispositiveinfinite(vmax);.

        Returns
        -------
        bool

        """
        return _BRepPrim.BRepPrim_OneAxis_VMaxInfinite(self, *args)

    def VMin(self, *args) -> "void":
        r"""
        No available documentation.

        Returns
        -------
        float
        No available documentation.

        Parameters
        ----------
        V: float

        Returns
        -------
        None

        """
        return _BRepPrim.BRepPrim_OneAxis_VMin(self, *args)

    def VMinInfinite(self, *args) -> "Standard_Boolean":
        r"""
        Returns true if vmin is infinite. default precision::isnegativeinfinite(vmax);.

        Returns
        -------
        bool

        """
        return _BRepPrim.BRepPrim_OneAxis_VMinInfinite(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _BRepPrim.delete_BRepPrim_OneAxis

# Register BRepPrim_OneAxis in _BRepPrim:
_BRepPrim.BRepPrim_OneAxis_swigregister(BRepPrim_OneAxis)

class BRepPrim_Revolution(BRepPrim_OneAxis):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Create a revolution body <m> is the meridian nd must be in the xz plane of <a>. <pm> is the meridian in the xz plane.

        Parameters
        ----------
        A: gp_Ax2
        VMin: float
        VMax: float
        M: Geom_Curve
        PM: Geom2d_Curve

        Returns
        -------
        None

        """
        _BRepPrim.BRepPrim_Revolution_swiginit(self, _BRepPrim.new_BRepPrim_Revolution(*args))

    __repr__ = _dumps_object

    __swig_destroy__ = _BRepPrim.delete_BRepPrim_Revolution

# Register BRepPrim_Revolution in _BRepPrim:
_BRepPrim.BRepPrim_Revolution_swigregister(BRepPrim_Revolution)

class BRepPrim_Wedge(BRepPrim_GWedge):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Default constructor.

        Returns
        -------
        None
        Creates a wedge algorithm. <axes> is the axis system for the primitive. //! xmin, ymin, zmin are set to 0 xmax, ymax, zmax are set to dx, dy, dz z2min = zmin z2max = zmax x2min = xmin x2max = xmax the result is a box dx,dy,dz should be positive.

        Parameters
        ----------
        Axes: gp_Ax2
        dx: float
        dy: float
        dz: float

        Returns
        -------
        None
        Creates a wedge primitive. <axes> is the axis system for the primitive. //! xmin, ymin, zmin are set to 0 xmax, ymax, zmax are set to dx, dy, dz z2min = zmin z2max = zmax x2min = ltx x2max = ltx the result is a step right angular wedge dx,dy,dz should be positive ltx should not be negative.

        Parameters
        ----------
        Axes: gp_Ax2
        dx: float
        dy: float
        dz: float
        ltx: float

        Returns
        -------
        None
        Create a wedge primitive. <axes> is the axis system for the primitive. //! all the fields are set to the corresponding value xyzmax - xyzmin should be positive zx2max - zx2min should not be negative.

        Parameters
        ----------
        Axes: gp_Ax2
        xmin: float
        ymin: float
        zmin: float
        z2min: float
        x2min: float
        xmax: float
        ymax: float
        zmax: float
        z2max: float
        x2max: float

        Returns
        -------
        None

        """
        _BRepPrim.BRepPrim_Wedge_swiginit(self, _BRepPrim.new_BRepPrim_Wedge(*args))

    __repr__ = _dumps_object

    __swig_destroy__ = _BRepPrim.delete_BRepPrim_Wedge

# Register BRepPrim_Wedge in _BRepPrim:
_BRepPrim.BRepPrim_Wedge_swigregister(BRepPrim_Wedge)

class BRepPrim_Cone(BRepPrim_Revolution):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        The step definition angle = semi-angle of the cone position : the coordinate system height : height of the cone. radius : radius of truncated face at z = 0 //! the apex is on z < 0 //! errors : height < resolution angle < resolution / height angle > pi/2 - resolution / height.

        Parameters
        ----------
        Angle: float
        Position: gp_Ax2
        Height: float
        Radius: float,optional
        	default value is 0

        Returns
        -------
        None
        Infinite cone at origin on z negative.

        Parameters
        ----------
        Angle: float

        Returns
        -------
        None
        Infinite cone at apex on z negative.

        Parameters
        ----------
        Angle: float
        Apex: gp_Pnt

        Returns
        -------
        None
        Infinite cone with axes.

        Parameters
        ----------
        Angle: float
        Axes: gp_Ax2

        Returns
        -------
        None
        Create a cone at origin on z axis, of height h, radius r1 at z = 0, r2 at z = h, x is the origin of angles. if r1 or r2 is 0 there is an apex. otherwise, it is a truncated cone. //! error : r1 and r2 < resolution r1 or r2 negative abs(r1-r2) < resolution h < resolution h negative.

        Parameters
        ----------
        R1: float
        R2: float
        H: float

        Returns
        -------
        None
        Same as above but at a given point.

        Parameters
        ----------
        Center: gp_Pnt
        R1: float
        R2: float
        H: float

        Returns
        -------
        None
        Same as above with given axes system.

        Parameters
        ----------
        Axes: gp_Ax2
        R1: float
        R2: float
        H: float

        Returns
        -------
        None

        """
        _BRepPrim.BRepPrim_Cone_swiginit(self, _BRepPrim.new_BRepPrim_Cone(*args))

    __repr__ = _dumps_object

    __swig_destroy__ = _BRepPrim.delete_BRepPrim_Cone

# Register BRepPrim_Cone in _BRepPrim:
_BRepPrim.BRepPrim_Cone_swigregister(BRepPrim_Cone)

class BRepPrim_Cylinder(BRepPrim_Revolution):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        The step definition position : center of a face and axis radius : radius of cylinder height : distance between faces on positive side //! errors : height < resolution radius < resolution.

        Parameters
        ----------
        Position: gp_Ax2
        Radius: float
        Height: float

        Returns
        -------
        None
        Infinite cylinder at origin on z negative.

        Parameters
        ----------
        Radius: float

        Returns
        -------
        None
        Infinite cylinder at center on z negative.

        Parameters
        ----------
        Center: gp_Pnt
        Radius: float

        Returns
        -------
        None
        Infinite cylinder at axes on z negative.

        Parameters
        ----------
        Axes: gp_Ax2
        Radius: float

        Returns
        -------
        None
        Create a cylinder at origin on z axis, of height h and radius r error : radius < resolution h < resolution h negative.

        Parameters
        ----------
        R: float
        H: float

        Returns
        -------
        None
        Same as above but at a given point.

        Parameters
        ----------
        Center: gp_Pnt
        R: float
        H: float

        Returns
        -------
        None

        """
        _BRepPrim.BRepPrim_Cylinder_swiginit(self, _BRepPrim.new_BRepPrim_Cylinder(*args))

    __repr__ = _dumps_object

    __swig_destroy__ = _BRepPrim.delete_BRepPrim_Cylinder

# Register BRepPrim_Cylinder in _BRepPrim:
_BRepPrim.BRepPrim_Cylinder_swigregister(BRepPrim_Cylinder)

class BRepPrim_Sphere(BRepPrim_Revolution):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Creates a sphere at origin with radius. the axes of the sphere are the reference axes. an error is raised if the radius is < resolution.

        Parameters
        ----------
        Radius: float

        Returns
        -------
        None
        Creates a sphere with center and radius. axes are the referrence axes. this is the step constructor.

        Parameters
        ----------
        Center: gp_Pnt
        Radius: float

        Returns
        -------
        None
        Creates a sphere with given axes system.

        Parameters
        ----------
        Axes: gp_Ax2
        Radius: float

        Returns
        -------
        None

        """
        _BRepPrim.BRepPrim_Sphere_swiginit(self, _BRepPrim.new_BRepPrim_Sphere(*args))

    __repr__ = _dumps_object

    __swig_destroy__ = _BRepPrim.delete_BRepPrim_Sphere

# Register BRepPrim_Sphere in _BRepPrim:
_BRepPrim.BRepPrim_Sphere_swigregister(BRepPrim_Sphere)

class BRepPrim_Torus(BRepPrim_Revolution):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        The step definition position : center and axes major, minor : radii //! errors : major < resolution minor < resolution.

        Parameters
        ----------
        Position: gp_Ax2
        Major: float
        Minor: float

        Returns
        -------
        None
        Torus centered at origin.

        Parameters
        ----------
        Major: float
        Minor: float

        Returns
        -------
        None
        Torus at center.

        Parameters
        ----------
        Center: gp_Pnt
        Major: float
        Minor: float

        Returns
        -------
        None

        """
        _BRepPrim.BRepPrim_Torus_swiginit(self, _BRepPrim.new_BRepPrim_Torus(*args))

    __repr__ = _dumps_object

    __swig_destroy__ = _BRepPrim.delete_BRepPrim_Torus

# Register BRepPrim_Torus in _BRepPrim:
_BRepPrim.BRepPrim_Torus_swigregister(BRepPrim_Torus)





